;****************************************************************************
;*																			*
;*						40 x 24 LCD Terminal / LCD Controller				*
;*																			*
;*								Version 1.0									*
;*																			*
;*								 by Benedikt								*
;*																			*
;*						Email:	benedikt83 t gmx.net						*
;*																			*
;****************************************************************************
;*																			*
;*	Die Software darf frei kopiert und verndert werden, solange sie nicht	*
;*	ohne meine Erlaubnis fr kommerzielle Zwecke eingesetzt wird.			*
;*																			*
;****************************************************************************
;*																			*
;*	Diese Software steuert ein 320x240 LCD an, und zeigt auf diesem 20 		*
;*	Zeilen Text mit je 40 zeichen an (8x12 Zeichensatz).					*
;*																		 	*
;****************************************************************************

.include "m32def.inc"


.equ Fuellzeichen	= ' '


; Im Interrupt genutzte und genderte Register:
.def regsave		= r2
.def CL2_L			= r3
.def CL2_H			= r4
.def PixZei_Cnt		= r5		; Pixel-Zeilen-Counter
.def Spalt_Cnt		= r6		; Spalten Counter fr die Zeichen

; R16 bis R 25 Registersatz mit erweitertem Befehlssatz 
.def Zeile_Cnt		= r16		; Zeilen Counter fr die Zeichen
.def ZeiHoehe_Cnt	= r17		; Counter fr die Zeichenhoehe
.def tempi			= r18

; Sonstige Register:
.def Akku_A			= r0
.def Akku_B			= r1


.def Daten			= r7
.def ERROR_CODE		= r8
.def ERROR_PARAM	= r9
.def Cur_Zaehl_1	= r10
.def Cur_Zaehl_2	= r11
.def Akku_C			= r12
.def Akku_D			= r13
.def Cursor			= r14


.def temp			= r19
.def temp2			= r20
.def AusgabeByte	= r21

; ITP2-Register
.def BA_mode		= r22		; 0=INI, 1=RD, 2=WR 
.def RECEIVE_MODE	= r23		; 0=RECEIVE_CONOUT, 1=RECEIVE_DEVCODE, 2=RECEIVE_ERROR_CODE
.def SEND_MODE		= r24		; 0=NO_SEND_MODE, 1=SEND_CONOUT
.def TermMode		= r25		; 0=Normal_TM, 1=IBM_ESC_TM, 2=IBM_CSI_TM,
								; 3=IBM_CSI_TM_Par, 4=IBM_CSI_TM_Par_Zeile

; BA_mode -> 0=INI, 1=RD, 2=WR
.equ 	BA_INI		= 0			
.equ 	BA_RD		= 1	
.equ 	BA_WR		= 2	


; RECEIVE_MODE ->   0=NO_RECEIVE_MODE, 1=RECEIVE_CONOUT, 2=RECEIVE_DEVCODE, 3=RECEIVE_ERROR_CODE
.equ 	NO_RECEIVE_MODE		= 0
.equ 	RECEIVE_CONOUT		= 1			
.equ 	RECEIVE_DEVCODE		= 2	
.equ 	RECEIVE_ERROR_CODE	= 3	


; SEND_MODE -> 0=NO_SEND_MODE, 1=SEND_CONOUT
.equ 	NO_SEND_MODE		= 0			
.equ 	SEND_CONOUT			= 1	


; TermMode -> 0=Normal_TM, 1=IBM_ESC_TM, 2=IBM_CSI_TM,
;             3=IBM_CSI_TM_Par, 4=IBM_CSI_TM_Par_Zeile 
.equ Normal_TM				= 0
.equ IBM_ESC_TM				= 1
.equ IBM_CSI_TM				= 2
.equ IBM_CSI_TM_Par			= 3
.equ IBM_CSI_TM_Par_Zeile	= 4


; Code-Tabelle fuer die Befehle
.equ 	RE_CONST		= 1		; Code fuer RECEIVE CONST 
.equ 	RE_CONIN		= 2		; Code fuer RECEIVE CONIN 
.equ 	SE_CONOUT		= 3		; Code fuer SEND CONOUT
.equ 	RE_SECNT		= 4		; Code fuer RECEIVE SECTOR COUNT
.equ 	RE_SECTOR		= 5		; Code fuer RECEIVE SECTOR
.equ 	RE_RD_ISEC		= 6		; Code fuer RECEIVE READ IMAGE SECTOR
.equ 	SE_WR_ISEC		= 7		; Code fuer SEND WRITE IMAGE SECTOR
.equ 	SE_STD			= 8		; Code fuer SEND SECTOR, TRACK, DRIVE
.equ 	SE_LIST			= 9		; Code fuer SEND LIST
.equ 	RE_ERROR_CODE	= 10	; Code fuer RECEIVE ERROR CODE
.equ 	RE_SAVE_RAM2FL	= 11	; Code fuer RECEIVE SAVE RAM-Floppy (RAM in FLASH brennen)
.equ 	RE_COPY_FL2RAM	= 12	; Code fuer RECEIVE COPY RAM-Floppy (FLASH in RAM copieren)
.equ 	SE_SECNT		= 14	; Code fuer SEND SECTOR COUNT

.equ 	RE_WHO_ARE_YOU 	=20		; Code fuer Abfrage der Funktionalitaet
								; des angeschlossenen Geraetes


; Code-Tabelle fuer den Device-Code
.equ 	DEVCODE_PC_CPM_EMU	= 2	;  // Code fuer PC-CP/M-Emulator
.equ 	DEVCODE_KEYBOARD	= 3	;  // Code fuer Tastatur
.equ 	DEVCODE_DISPLAY		= 4	;  // Code fuer LCD-Display
.equ 	DEVCODE_RAMFLOPPY	= 5	;  // Code fuer RAM-Floppy


; Nachricht auf die Anfrage "Wer bist Du?" RE_WHO_ARE_YOU ist
; die Nachricht "Wer bin ich?" MESSAGE_WHO_AM_I

;  !!!!! Achtung diese Zeile muss bei jedem Geraet angepasst werden !!!!!

.equ 	MESSAGE_WHO_AM_I	= DEVCODE_DISPLAY



; Register X (R26,R27) enthaelt den Zeiger auf den BWS im RAM fuer die Interruptroutine
; Register Y (R28,R29) enthaelt den Zeiger auf den BWS im RAM fuer den Cursor (aktuelle Position)
; Register Z (R30,R31) enthaelt den Zeiger auf den Font im Flash (mit aktuellem Offset)

; Z: Pointer auf die Schriftart (ZL: ASCII Code, ZH Pixelzeile)




; PortA = D0..D3 des Displays
; PA4..PA7 frei

; PortB = D0..D3 des ITP2-Connectors
; PB5=MOSI, PB6=MISO, PB6=SCK -> waehrend der Programmierung fuer SPI genutzt (im Betrieb frei)


; PortC
; PC2..PC3 frei
.equ 	DDWR		=7			; ITP2 -> DDWR = Eingang
.equ 	DDAC		=4			; ITP2 -> DDAC = Ausgang
.equ 	CDEN		=6			; ITP2 -> CDEN { 1=Ausgang, 0=Eingang }
.equ 	CRAC		=5			; ITP2 -> CRAC { 1=Ausgang, 0=Eingang }

.equ 	LCD_ON_OFF	=1			; Ein/Ausschalten der LCD-Kontrastspannung (Ausgang)
.equ 	SPEAKER		=0			; Lautsprecher (Ausgang)



; PortD
; PD0=RxD, PD1=TxD
.equ 	FLM			=2			; FLM, First Line Marker (VSync)
.equ 	M			=3			; M, AC Drive
.equ 	CL1			=4			; CL1, Latch Puls (HSync)
.equ 	CL2			=5			; CL2, Pixelclock
.equ 	LED_GRUEN	=6			; gruene LED
.equ 	LED_ROT		=7			; rote LED



;Werte
.equ Framerate		=50			; Refreshrate
.equ F_CPU			=18000000	; CPU Freq in MHz

; Interne Konstanten
.equ PixelZeilen	=200
.equ HFREQ			=Framerate*PixelZeilen
.equ TDIV			=((F_CPU/8+(HFREQ)/2)/HFREQ)
.equ Zeichenhoehe	=8			; 8, 10, 12
.equ maxSpalten		=78			; maximale physikalische Spaltenzahl minus 2 
								; 80-2 -> muss eine gerade Zahl sein
.equ maxSpalten_Half 	=maxSpalten/2
.equ maxZeilen		=(PixelZeilen/Zeichenhoehe)-1



;****************************************************************************
;	RAM = Datensegment
;****************************************************************************


.dseg
BWS:
		.byte	maxSpalten*maxZeilen		;Bildwiederholspeicher

CSI_P1:
		.db		0
CSI_P2:
		.db		0

;****************************************************************************
;	Interrupt Vektoren
;****************************************************************************

.cseg
.org 0
rjmp Reset

.org OC2addr				;Bildbeginn

	; retten des Statusregisters nach Aufruf der Interruptroutine 
	in 		regsave, sreg


	; vorbereiten der Registers fuer
	in 		tempi, PORTD
	; CL2 = 0
	cbr 	tempi, 1<<CL2
	mov 	CL2_L, tempi
	; und CL2 = 1
	sbr 	tempi, 1<<CL2
	mov 	CL2_H, tempi


	; Inkrementiern des Pixel-Zeilen-Counters
	inc		PixZei_Cnt

	; ueberspringen der ersten 4 Pixelzeilen
	ldi 	tempi, 5
	cp		PixZei_Cnt, tempi		; 1..4 - 5 = Curry  
	brcc	hloop_a

	rjmp	hloop_k

hloop_a:

	; ueberspringen der letzten 4 Pixelzeilen
	ldi 	tempi, PixelZeilen-4
	cp		tempi, PixZei_Cnt		; 196 - (197..200) = Curry
	brcc	hloop_b

	rjmp	hloop_k

hloop_b:

	; Lade Spalt_Cnt mit maxSpalten
	ldi 	tempi, maxSpalten
	mov 	Spalt_Cnt, tempi


	; Ein Byte am Zeilenanfang mit Leerzeichen anzeigen
	ldi		tempi, 0

	out		PORTD, CL2_L
	nop						
	nop						
	out		PORTD, CL2_H
	out		PORTA, tempi
	out		PORTD, CL2_L
	nop			
	nop	
	out		PORTD, CL2_H
	out		PORTA, tempi


	; Loop fr 1 Zeile
hloop_c:	
	out 	PORTD, CL2_L		; PCLK L				1	-> 4 Takte H
	ld 		ZL, X+				; ASCII aus RAM lesen	2
	lpm		 tempi, Z			; Byte aus CGROM lesen	3
	out 	PORTD, CL2_H		; PCLK H				1	-> 4 Takte L
	out		 PORTA, tempi		; Low Nibble ausgeben	1
	out 	PORTD, CL2_L		; PCLK L				1	-> 2 Takte H
	swap 	tempi				; 						1
	out 	PORTA, tempi		; High Nibble ausgeben	1
	out 	PORTD, CL2_H		; PCLK H				1	-> 3 Takte L
	dec	 	Spalt_Cnt			;						1
	brne 	hloop_c				;						2
								;					  =15 Takte pro Byte	
			

	; Ein Byte am Zeilenende mit Leerzeichen anzeigen
	ldi		tempi, 0

	out		PORTD, CL2_L
	nop						
	nop						
	out		PORTD, CL2_H
	out		PORTA, tempi
	out		PORTD, CL2_L
	nop			
	nop	
	out		PORTD, CL2_H
	out		PORTA, tempi
			
			
			
	; CL2 auf 0
	out 	PORTD, CL2_L			; PCLK L

	; Schalten von CL1 und FLM
	sbi 	PORTD, CL1
	dec 	ZeiHoehe_Cnt			; Zhler fr Zeichenhhe erniedrigen
	nop
	nop
	cbi 	PORTD, CL1
	cbi 	PORTD, FLM
	breq 	skipcloop				; 1 Textzeile fertig ausgegeben ?
	inc 	ZH						; Nein -> Bilddatenadresse fr nchste Pixelzeile laden und

	sbiw 	XL, maxSpalten_Half		; Textadresse wieder an Anfang der Textzeile setzen
	sbiw 	XL, maxSpalten_Half	 

	rjmp 	exit_int

	; Alles fr neue Textzeile einrichten
skipcloop:				
	ldi 	ZH, 8					; 1024Bytes CGROM Offset
	ldi 	ZeiHoehe_Cnt, Zeichenhoehe	; Zeichenhhen Counter laden
	inc 	Zeile_Cnt				; Zeilencounter erhhen
	cpi 	Zeile_Cnt, maxZeilen	; Bildende ?
	brne 	exit_int


exit_int:
	; zurueckholen des Statusregisters nach Abarbeitung der Interruptroutine 
	out 	sreg, regsave

	reti
	



hloop_k:
	; Lade Spalt_Cnt mit maxSpalten
	ldi 	tempi, maxSpalten+2
	mov 	Spalt_Cnt, tempi

	; Ein Byte am Zeilenanfang mit Leerzeichen anzeigen
	ldi		tempi, 0

hloop_l:
	out		PORTD, CL2_L
	nop						
	nop						
	out		PORTD, CL2_H
	out		PORTA, tempi
	out		PORTD, CL2_L
	nop			
	nop	
	out		PORTD, CL2_H
	out		PORTA, tempi
	;
	dec	 	Spalt_Cnt
	brne 	hloop_l		

	; CL2 auf 0
	out 	PORTD, CL2_L			; PCLK L

	; Schalten von CL1 und FLM
	sbi 	PORTD, CL1
	nop
	nop
	cbi 	PORTD, CL1
	cbi 	PORTD, FLM

	; ist die letzte Bildschirmzeile geschrieben?
	ldi 	tempi, PixelZeilen
	cp		PixZei_Cnt, tempi
	brne	hloop_m

	; Abschluss des Bildschirms

	; Toggeln von M
	sbis 	PORTD, M
	sbi 	PORTD, M
	sbic	 PIND, M
	cbi 	PORTD, M

	; Grundeinstellungen
	clr		PixZei_Cnt
	clr		Zeile_Cnt
	ldi		XL, low(BWS)
	ldi		XH, high(BWS)

	; setzen von FLM
	sbi 	PORTD, FLM

hloop_m:

	; zurueckholen des Statusregisters nach Abarbeitung der Interruptroutine 
	out 	sreg, regsave

	reti



;****************************************************************************
;	CPU Register Initialisierung
;****************************************************************************

Reset:
	; Setzen des StackPointers
	ldi		temp, low(RAMEND)
	out		SPL, temp					;setup stack pointer
	ldi		temp, high(RAMEND)
	out		SPH, temp					;setup stack pointer



	; Initialisieren der Ausgabeports
	; PortA => D0..D3 des Displays (immer als Ausgang) 
	ldi 	temp, 0b00001111
	out 	DDRA, temp

	; PortB => D0..D3 des ITP2-Connectors (erstmal als Eingang) 
	ldi 	temp, 0b00000000
	out 	DDRB, temp

	ldi 	temp, 0b10010000
	out 	PORTC, temp

	; PortC => PC0=SPEAKER (A), PC1=LCD_ON_OFF (A), PC2..PC3 frei, 
	;          PC4=DDAC (A), PC5=CRAC (E), PC6=CDEN (E), PC7=DDWR (E) 
	ldi 	temp, 0b00010011
	out 	DDRC, temp

	ldi 	temp, 0b10010000
	out 	PORTC, temp

	; PortD => PD0=RxD (E), PD1=TxD (A), PD2=FLM (A), PD3=M (A), PD4=CL1 (A), PD5=CL2 (A), 
	;          PD6=LED_GRUEN (A), PD7=LED_ROT (A), 
	ldi 	temp, 0b11111110
	out 	DDRD, temp

	; alle Ausgaenge auf 0 setzen
	clr		temp	
	out 	PORTA, temp
	out 	PORTB, temp
	out 	PORTD, temp



	; *** Initialisieren des Timers ***
	; setzend des Triggerwertes, bei dem der Interrupt ausgeloest wird
	ldi 	temp, TDIV-1
	out		OCR2, temp

	; Einstellen des Vorteilers aus 
	ldi 	temp, (1<<WGM21)|2			; CTC
	out		TCCR2, temp

	; Interrupt aktiviern fuer Output Compare Match 2
	ldi		temp, (1<<OCIE2)			; Compare2 Interrupt: Beginn der Datenausgabe
	out	 	TIMSK, temp







;****************************************************************************
;	Variablen Initialisierung
;****************************************************************************

	clr		temp
	clr		temp2

	; setzen von Y mit Zeiger auf den BWS im RAM
	ldi		YL, low(BWS)
	ldi		YH, high(BWS)

	; temp -> Leerzeichen
	ldi		temp, Fuellzeichen
	; voll schreiben des Bildspeicher mit ASCII-Zeichensatz
clrloop:
	; Abspeichern von temp (!"...) in DDRAM
	st		Y+, temp
	inc		temp
	; ist das Ende des DDRAM (Bildspeicher=XSize*YSize) erreicht?
	ldi		temp2, high(maxSpalten*maxZeilen+BWS)
	cpi		YL, low(maxSpalten*maxZeilen+BWS)
	cpc		YH, temp2
	; wenn nicht nochmal ...
	brne	clrloop


	; Grundeinstellungen
	clr		Zeile_Cnt
	clr		PixZei_Cnt
	; setzen X auf Bildspeicher DDRAM
	ldi		XL, low(BWS)
	ldi		XH, high(BWS)

	ldi 	ZH, 8						; 1024Bytes CGROM Offset
	ldi 	ZeiHoehe_Cnt, Zeichenhoehe	; Zeichenhhen Counter laden


	; BA_mode = BA_INI
	ldi 	BA_mode, BA_INI

	; RECEIVE_MODE = RECEIVE_CONOUT
	ldi 	RECEIVE_MODE, NO_RECEIVE_MODE 

	; SEND_MODE = NO_SEND_MODE
	ldi 	SEND_MODE, NO_SEND_MODE

	; TermMode = Normal_TM 
	ldi 	TermMode, Normal_TM


	; Grundeinstellung des Cursor-Zaehlers
	clr		temp
	mov		Cur_Zaehl_1, temp
	mov		Cur_Zaehl_2, temp


	; SEI = Set Global Interrupt Flag
	sei

	; Ausschalten der beiden LED
	cbi 	PORTD, LED_ROT
	cbi 	PORTD, LED_GRUEN


	; Einschalten der -24V Spannung
	sbi 	PORTC, LCD_ON_OFF









;****************************************************************************
;	Hauptprogramm
;****************************************************************************

Mainloop:

	; Cursor-Zaehler
	dec		Cur_Zaehl_1
	brne	Mainloop_A



		dec		Cur_Zaehl_2	
		brne	Mainloop_A






		rcall	LCD_CURSOR

Mainloop_A:


	; Verzweigung je nach Betriebsart-Mode
	; 0=INI, 1=RD, 2=WR
	cpi		BA_mode, BA_RD	; 1=RD	
	brne	BA_mode_WR

	rcall	RUN_BA_mode_RD	
	rjmp	Mainloop

BA_mode_WR:
	cpi		BA_mode, BA_WR	; 2=WR	
	brne	BA_mode_INI

	rcall	RUN_BA_mode_WR
	rjmp	Mainloop	
		
BA_mode_INI:

	rcall	RUN_BA_mode_INI	; 0=INI	
	rjmp	Mainloop





;****************************************************************************
;	ITP2
;****************************************************************************



; Betriebsart-Mode = RD
RUN_BA_mode_RD:

	; *** Ueberspringen der Verzweigung, 
	; falls RECEIVE_MODE <> NO_RECEIVE_MODE ***

	cpi		RECEIVE_MODE, NO_RECEIVE_MODE
	breq	RUN_BA_mode_RD_X	



	; *** Verzweigung nach -> RECEIVE_MODE ***


	; RECEIVE_CONOUT : RUN_RECEIVE_CONOUT;
	cpi		RECEIVE_MODE, RECEIVE_CONOUT
	brne	RUN_BA_mode_RD_A

	rcall	RUN_RECEIVE_CONOUT
	rjmp	RUN_BA_mode_RD_X

RUN_BA_mode_RD_A:

	; RECEIVE_DEVCODE : RUN_RECEIVE_DEVCODE;
	cpi		RECEIVE_MODE, RECEIVE_DEVCODE
	brne	RUN_BA_mode_RD_B

	rcall	RUN_RECEIVE_DEVCODE

	rjmp	RUN_BA_mode_RD_X

RUN_BA_mode_RD_B:

	; RECEIVE_ERROR_CODE : RUN_RECEIVE_ERROR_CODE;
	cpi		RECEIVE_MODE, RECEIVE_ERROR_CODE
	brne	RUN_BA_mode_RD_C

	rcall	RUN_RECEIVE_ERROR_CODE
	rjmp	RUN_BA_mode_RD_X

RUN_BA_mode_RD_C:



RUN_BA_mode_RD_X:


	; wenn der DDWR von 0 auf 1 gesetzt wurde (DDWR ist gesetzt), dann soll die 
	; Betriebsart-Mode auf WR gesetzt werden und es wird 
	sbic	PINC, DDWR			; Ueberspringen des rcall, wenn DDWR geloescht ist 
		; das Unterprogramm RUN_BA_mode_SET_WR aufgerufen
		rcall	RUN_BA_mode_SET_WR


	ret


; ...........................


; Betriebsart-Mode = WR
RUN_BA_mode_WR:


	; ist CDEN_E=1, dann hat der Server Daten gesendet
	in		temp, PINC
	bst		temp, CDEN
	; ist CDEN=0 (T=0) dann ueberspringe das Einlesen
	brtc	RUN_BA_mode_WR_X


	; nun folgen die Anweisungen zum Einlesen der Daten


	nop
	nop


	; Daten aus Port B lesen
	in		temp2, PINB
	; es sind aber nur D0-D3 Daten, die anderen werden ausgeblendet 
	andi	temp2, 0b00001111


	; CRAC = 1 -> Bestaetigung des Einlesens an den Server
	sbi 	PORTC, CRAC


	; warten solange CDEN=1 ist (Server haelt die Daten als aktiv)
RUN_BA_mode_WR_A:
	in		temp, PINC
	bst		temp, CDEN
	brts	RUN_BA_mode_WR_A


	; CRAC = 0 -> Bestaetigung des Empfangs, dass die Daten nicht
	;             mehr aktiv sind
	cbi 	PORTC, CRAC


	; warten solange CDEN=0 ist (Server bereitet neue Daten zum Senden vor)
RUN_BA_mode_WR_B:
	in		temp, PINC
	bst		temp, CDEN
	brtc	RUN_BA_mode_WR_B


	; nun ist CDEN=1, d.h. der Server hat das 2. Nibble der Daten
	; auf den Datenport (PORTB) gelegt

	nop
	nop
	nop
	nop


	; Daten aus Port B lesen
	in		temp, PINB
	; es sind aber nur D0-D3 Daten, die anderen werden ausgeblendet 
	andi	temp, 0b00001111


	; CRAC = 1 -> Bestaetigung des Einlesens an den Server
	sbi 	PORTC, CRAC


	; das letzte Nibble ist das hoehere und wird
	; 4 mal nach links verschoben
	lsl		temp		
	lsl		temp
	lsl		temp
	lsl		temp


	; zusammenfassen der beiden Daten-Nibble zu einem Datenbyte
	or		temp2, temp


	; weiter verarbeiten der Daten
	mov		Daten, temp2
	rcall	DATA_SEND
	

	; warten solange CDEN=1 ist (Server haelt die Daten als aktiv)
RUN_BA_mode_WR_C:
	in		temp, PINC
	bst		temp, CDEN
	brts	RUN_BA_mode_WR_C


	; CRAC = 0 -> Bestaetigung des Empfangs, dass die Daten nicht
	;             mehr aktiv sind
	cbi 	PORTC, CRAC

RUN_BA_mode_WR_X:



	; wenn der DDWR von 1 auf 0 gesetzt wurde (DDWR ist geloescht), dann soll die 
	; Betriebsart-Mode auf RD gesetzt werden und es wird 
	sbis	PINC, DDWR			; Ueberspringen des rcall, wenn DDWR gesetzt ist 
		; das Unterprogramm RUN_BA_mode_SET_RD aufgerufen
		rcall	RUN_BA_mode_SET_RD


	ret


; ...........................



; Betriebsart-Mode = INI
RUN_BA_mode_INI:

	; wenn der DDWR von 1 auf 0 gesetzt wurde (DDWR ist geloescht), dann soll die 
	; Betriebsart-Mode auf RD gesetzt werden und es wird 
	sbis	PINC, DDWR			; Ueberspringen des rcall, wenn DDWR gesetzt ist 
		; das Unterprogramm RUN_BA_mode_SET_RD aufgerufen
		rcall	RUN_BA_mode_SET_RD

	ret




; ---------------------------
; | Aendern der Betriebsart |
; ---------------------------


; Setzen Betriebsart-Mode -> RD
RUN_BA_mode_SET_RD:

	; Umschalten auf Server = Lesen, Client = Schreiben

	; PortB => D0..D3 des ITP2-Connectors auf Ausgang stellen 
	ldi 	temp, 0b00001111
	out 	DDRB, temp

	; CDEN = 0 - Vorbelegung
	cbi 	PORTC, CDEN
	; CDEN = Ausgang
	sbi 	DDRC, CDEN

	; CRAC = Eingang
	cbi 	DDRC, CRAC

	; DDAC=0 -> RD = Bestaetigung der Umstellung
	cbi 	PORTC, DDAC

	; BA_Mode:=BA_mode_RD;
	ldi		BA_mode, BA_RD

	; Ruecksprung
	ret

; ...........................




; Setzen Betriebsart-Mode -> WR
RUN_BA_mode_SET_WR:

	; Umschalten auf Server = Schreiben, Client = Lesen

	; PortB => D0..D3 des ITP2-Connectors auf Eingang stellen 
	ldi 	temp, 0b00000000
	out 	DDRB, temp

	; CDEN = Eingang
	cbi 	DDRC, CDEN

	; CRAC = 0 - Vorbelegung
	cbi 	PORTC, CRAC

	; CRAC = Ausgang
	sbi 	DDRC, CRAC

	; DDAC=1 -> WR = Bestaetigung der Umstellung
	sbi 	PORTC, DDAC

	; BA_Mode:=BA_mode_WR;
	ldi		BA_mode, BA_WR

	; Ruecksprung
	ret

; ...........................








; ---------------------------
; |  Auswerten der Daten    |
; ---------------------------




; *** Verzweigung nach Zustaenden ***



; Auswerten des empfangenen Bytes nach
; dem SEND_MODE
DATA_SEND:


	; SEND_MODE = NO_SEND_MODE ?
	cpi		SEND_MODE, NO_SEND_MODE
	brne	DATA_SEND_A
		
	; SEND_MODE = NO_SEND_MODE
	rcall	change_mode
	rjmp 	DATA_SEND_X


DATA_SEND_A:
	; SEND_MODE = SEND_CONOUT ? 
	cpi		SEND_MODE, SEND_CONOUT
	brne	DATA_SEND_B
		
	; SEND_MODE = SEND_CONOUT
	mov		AusgabeByte, Daten

	; SEND_MODE:=NO_SEND_MODE;
	ldi		SEND_MODE, NO_SEND_MODE

	; RECEIVE_MODE := RECEIVE_CONOUT;
	ldi		RECEIVE_MODE, RECEIVE_CONOUT

	rjmp 	DATA_SEND_X

DATA_SEND_B:

	; wenn der SEND_MODE nicht ausgewertet werden konnte,
	; so wird er in ERROR_PARAM mit dem ERROR_CODE=2
	; abgespeichert und kann spaeter ausgewertet werden
	mov		ERROR_PARAM, SEND_MODE

	ldi		temp, 2
	mov		ERROR_CODE, temp

DATA_SEND_X:

	; Ruecksprung
	ret

; ...........................





; Auswerten des empfangenen Befehls in Daten
change_mode:

	mov		temp, Daten

	; Auswerten des gesendeten Befehls

	; Befehl = RE_WHO_ARE_YOU ?
	cpi		temp, RE_WHO_ARE_YOU 
	brne	change_mode_A

	; Befehl = RE_WHO_ARE_YOU
	ldi		RECEIVE_MODE, RECEIVE_DEVCODE
	rjmp 	change_mode_X

change_mode_A:

	; Befehl = RE_ERROR_CODE ?
	cpi		temp, RE_ERROR_CODE 
	brne	change_mode_B

	; Befehl = RE_ERROR_CODE
	ldi		RECEIVE_MODE, RECEIVE_ERROR_CODE
	rjmp 	change_mode_X

change_mode_B:

	; Befehl = SE_CONOUT ?
	cpi		temp, SE_CONOUT 
	brne	change_mode_C

	; Befehl = SE_CONOUT
	ldi		SEND_MODE, SEND_CONOUT
	rjmp 	change_mode_X

change_mode_C:

	; wenn der Befehl nicht ausgewertet werden konnte,
	; so wird er in ERROR_PARAM mit dem ERROR_CODE=1
	; abgespeichert und kann spaeter ausgewertet werden
	mov		ERROR_PARAM, temp

	ldi		temp, 1
	mov		ERROR_CODE, temp


change_mode_X:


	; Ruecksprung
	ret

; ...........................




; *** Senden an den Server ***


; sendet ein Byte (Daten) an die Z80
RUN_RECEIVE_MESSAGE:

	; ONE_NIBBLE := RECEIVE_MESSAGE and $0F;
	mov		temp2, Daten
	andi	temp2, 0b00001111

	rcall	SEND_ONE_NIBBLE


	; ONE_NIBBLE := RECEIVE_MESSAGE shr 4;
	mov		temp2, Daten
	; das zweite Nibble ist das hoehere und wird
	; 4 mal nach rechts verschoben (0 wird eingeschoben)
	lsr		temp2		
	lsr		temp2
	lsr		temp2
	lsr		temp2

	rcall	SEND_ONE_NIBBLE


	; Ruecksprung
	ret

; ...........................




; sendet ein Nibble (temp2) an die Z80
SEND_ONE_NIBBLE:


	; *** Senden des Nibble ***

	; PortB := ONE_NIBBLE;
	out		PORTB, temp2

	nop
	nop

	; CDEN = 1 -> Daten sind jetzt gueltig
	sbi 	PORTC, CDEN

	; warten bis der Server die Daten uebernommen hat
	; und dies mit CRAC=1 bestaetigt
SEND_ONE_NIBBLE_B:
	in		temp, PINC
	bst		temp, CRAC
	brtc	SEND_ONE_NIBBLE_B


	; erstmal alles auf 0 (CDEN=0)
	cbi 	PORTC, CDEN


	; warten bis der Server die Grundeinstellung von CRAC=0
	; eingenommen hat
SEND_ONE_NIBBLE_A:
	in		temp, PINC
	bst		temp, CRAC
	brts	SEND_ONE_NIBBLE_A


	; Ruecksprung
	ret

; ...........................






; AusgabeByte an CONOUT
RUN_RECEIVE_CONOUT:

	; Anzeige des Zeichens
	rcall	LCD_CONOUT

	; wieder Grundzustand einstellen
	ldi		RECEIVE_MODE, NO_RECEIVE_MODE

	; Ruecksprung
	ret

; ...........................




RUN_RECEIVE_DEVCODE:

	; RUN_RECEIVE_MESSAGE(MESSAGE_WHO_AM_I);
	ldi		temp, MESSAGE_WHO_AM_I
	mov		Daten, temp

	rcall	RUN_RECEIVE_MESSAGE

	; wieder Grundzustand einstellen
	ldi		RECEIVE_MODE, NO_RECEIVE_MODE

	; Ruecksprung
	ret

; ...........................



RUN_RECEIVE_ERROR_CODE:

	; RUN_RECEIVE_MESSAGE(ERROR_CODE);  // Fehlercode 0=kein Fehler
	mov		Daten, ERROR_CODE
	rcall	RUN_RECEIVE_MESSAGE

	; RUN_RECEIVE_MESSAGE(ERROR_PARAM);  // Parameter fuer Fehlercode
	mov		Daten, ERROR_PARAM
	rcall	RUN_RECEIVE_MESSAGE

	; wieder Grundzustand einstellen
	ldi		RECEIVE_MODE, NO_RECEIVE_MODE

	; Ruecksprung
	ret

; ...........................







; ------------------------------------
; |  Ausgabe der Zeichen an das LCD  |
; ------------------------------------





; Schaltet den Cursor abwechselnd auf das aktuelle Zeichen und "_"
LCD_CURSOR:

	; Abfragen des Zustandes des Cursors (ON/OFF)
	clr		temp
	cp		Cursor, temp
	brne	LCD_CURSOR_A

		; Cursor ist 0 = ON (Zeichen ist im BWS)
		ld		Cursor, Y	; Zeichen vom BWS in den Cursor-Speicher

		ldi		temp, '_'
		st		Y, temp		; '_' in BWS

		rjmp	LCD_CURSOR_B

LCD_CURSOR_A:

		; Cursor ist das aktuelle Zeichen = OFF (Zeichen im BWS='_')
		st		Y, Cursor	; Cursor in BWS
		clr		Cursor		; Loeschen des Cursors


LCD_CURSOR_B:


	; Abschalten der roten LED
	cbi 	PORTD, LED_ROT


	; Ruecksprung
	ret

; ...........................




LCD_CURSOR_OFF:
	
	; Abfragen des Zustandes des Cursors (ON/OFF)
	clr		temp
	cp		Cursor, temp
	breq	LCD_CURSOR_OFF_A

		; Cursor ist das aktuelle Zeichen = OFF (Zeichen im BWS='_')
		st		Y, Cursor	; Cursor in BWS
		clr		Cursor		; Loeschen des Cursors

LCD_CURSOR_OFF_A:

	; Grundeinstellung des Cursor-Zaehlers
	clr		temp
	mov		Cur_Zaehl_1, temp
	mov		Cur_Zaehl_2, temp


	; Ruecksprung
	ret

; ...........................




LCD_CONOUT:

	; kurzes Setzen der roten LED
	sbi 	PORTD, LED_ROT


	; Abschalten des Cursors
	rcall	LCD_CURSOR_OFF


	; *** Auswertung nach TermMode ***

	; TermMode = Normal_TM 
	cpi		TermMode, Normal_TM
	brne	LCD_CONOUT_A

	rcall	NTM
	rjmp	LCD_CONOUT_X


LCD_CONOUT_A:

	; TermMode = IBM_ESC_TM 
	cpi		TermMode, IBM_ESC_TM
	brne	LCD_CONOUT_B

	rcall	IETM
	rjmp	LCD_CONOUT_X

LCD_CONOUT_B:


	; TermMode = IBM_CSI_TM 
	cpi		TermMode, IBM_CSI_TM
	brne	LCD_CONOUT_C

	rcall	ICTM
	rjmp	LCD_CONOUT_X


LCD_CONOUT_C:

	; TermMode = IBM_CSI_TM_Par
	cpi		TermMode, IBM_CSI_TM_Par
	brne	LCD_CONOUT_D

	rcall	ICTMP
	rjmp	LCD_CONOUT_X


LCD_CONOUT_D:

	; TermMode = IBM_CSI_TM_Par_Zeile
	cpi		TermMode, IBM_CSI_TM_Par_Zeile
	brne	LCD_CONOUT_E

	rcall	ICTMPZ
	rjmp	LCD_CONOUT_X


LCD_CONOUT_E:

	; Meldung [TM] auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	ldi		AusgabeByte, '['
	rcall	NTM_CHAR

	ldi		AusgabeByte, 'T'
	rcall	NTM_CHAR

	ldi		AusgabeByte, 'M'
	rcall	NTM_CHAR

	pop		AusgabeByte
	rcall	NTM_CHAR

	ldi		AusgabeByte, ']'
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR

	ldi		TermMode, Normal_TM


LCD_CONOUT_X:


	; Ruecksprung
	ret

; ...........................









; TermMode = IBM_ESC_TM 
IETM:

	; 1BH = Escape
	cpi		AusgabeByte, '['
	brne	IETM_A

	ldi		TermMode, IBM_CSI_TM

	rjmp	IETM_X


IETM_A:

	; Meldung ESC auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	pop		AusgabeByte
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR

	ldi		TermMode, Normal_TM


IETM_X:

	; Ruecksprung
	ret
; .....




; TermMode = IBM_CSI_TM / Control Sequence Introducer (CSI) 
ICTM:

	; 30..39H -> Parameter 1
	cpi		AusgabeByte, 0x30
	brlo	ICTM_A

	cpi		AusgabeByte, 0x3A
	brge	ICTM_A

	rcall	AB_to_CSI_P1

	ldi		TermMode, IBM_CSI_TM_Par
	rjmp	ICTM_X

ICTM_A:

	; Lschen bis Zeilenende / ESC [ K
	cpi		AusgabeByte, 'K'
	brne	ICTM_B

	rcall	DELETE_EOL
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTM_X


ICTM_B:
 
	; Schirm lschen / ESC [ f
	cpi		AusgabeByte, 'f'
	brne	ICTM_D





	; Setzen der gruenen LED
	sbi 	PORTD, LED_GRUEN






	rcall	NTM_CLS_A
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTM_X

ICTM_D:

	; Meldung ESC auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	ldi		AusgabeByte, '['
	rcall	NTM_CHAR

	pop		AusgabeByte
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR

	ldi		TermMode, Normal_TM

ICTM_X:

	; Ruecksprung
	ret
; .....







; TermMode = IBM_CSI_TM_Par
ICTMP:

	; 30..39H -> Parameter 1
	cpi		AusgabeByte, 0x30
	brlo	ICTMP_A

	cpi		AusgabeByte, 0x3A
	brge	ICTMP_A

	rcall	AB_to_CSI_P1

	ldi		TermMode, IBM_CSI_TM_Par
	rjmp	ICTMP_X


ICTMP_A:

	; ";" -- MOVE CURSOR = ESC [ Pn1 ; PN2 H oder ESC [ Pn1 ; PN2 f
	cpi		AusgabeByte, ';'
	brne	ICTMP_B

	rcall	Clear_CSI_P1
	ldi		TermMode, IBM_CSI_TM_Par_Zeile

	rjmp	ICTMP_X


ICTMP_B:

	; CUU -- Cursor Up = ESC [ Pn A
	cpi		AusgabeByte, 'A'
	brne	ICTMP_C

	; CSI_P1 in AusgabeByte laden
	rcall	CSI_P1_to_AB


ICTMP_B1:
	; einmal Cursor Up
	rcall	NTM_CurUp_B

	; Zaehler dekrementieren
	dec		AusgabeByte

	; wiederholen solange wie CSI_P1
	brne	ICTMP_B1


	; Grundeinstellungen
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X


ICTMP_C:

	; CUD -- Cursor Down = ESC [ Pn B
	cpi		AusgabeByte, 'B'
	brne	ICTMP_D

	; CSI_P1 in AusgabeByte laden
	rcall	CSI_P1_to_AB


ICTMP_C1:
	; einmal Cursor Down
	rcall	NTM_Cur_Down_B

	; Zaehler dekrementieren
	dec		AusgabeByte

	; wiederholen solange wie CSI_P1
	brne	ICTMP_C1


	; Grundeinstellungen
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X


ICTMP_D:

	; CUD -- CUF -- Cursor Forward  = ESC [ Pn C
	cpi		AusgabeByte, 'C'
	brne	ICTMP_E

	; CSI_P1 in AusgabeByte laden
	rcall	CSI_P1_to_AB


ICTMP_D1:

	; einmal Cursor Right
	rcall	NTM_CurRight_B

	; Zaehler dekrementieren
	dec		AusgabeByte

	; wiederholen solange wie CSI_P1
	brne	ICTMP_D1


	; Grundeinstellungen
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X


ICTMP_E:

	; CUB -- Cursor Backward = ESC [ Pn D
	cpi		AusgabeByte, 'D'
	brne	ICTMP_F

	; CSI_P1 in AusgabeByte laden
	rcall	CSI_P1_to_AB


ICTMP_E1:

	; einmal Cursor Right
	rcall	NTM_Cur_Left_B

	; Zaehler dekrementieren
	dec		AusgabeByte

	; wiederholen solange wie CSI_P1
	brne	ICTMP_E1


	; Grundeinstellungen
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X


ICTMP_F:

	; ERASE LINE = ESC [ Pn K
	cpi		AusgabeByte, 'K'
	brne	ICTMP_G

	; CSI_P1 in AusgabeByte laden
	rcall	CSI_P1_to_AB


	; Ausgabebyte = 0 -> DELETE_EOL
	; Von Cursor bis Ende
	cpi		AusgabeByte, 0
	brne	ICTMP_F1

	rcall	DELETE_EOL

	rjmp	ICTMP_F9


ICTMP_F1:

	; Ausgabebyte = 1 -> DELETE_BOL
	; Von Anfang bis Cursor
	cpi		AusgabeByte, 1
	brne	ICTMP_F2

	rcall	DELETE_BOL

	rjmp	ICTMP_F9


ICTMP_F2:

	; Ausgabebyte = 2 -> DELETE_LINE
	; Ganze Zeile loeschen
	cpi		AusgabeByte, 1
	brne	ICTMP_F3

	rcall	DELETE_LINE

	rjmp	ICTMP_F9


ICTMP_F3:

	; Meldung ESC auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	ldi		AusgabeByte, '['
	rcall	NTM_CHAR

	pop		AusgabeByte
	rcall	NTM_CHAR

	ldi		AusgabeByte, 'K'
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR


ICTMP_F9:

	; Grundeinstellungen
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X


ICTMP_G:

	; Bildschirm loeschen = ESC [ Pn J
	cpi		AusgabeByte, 'J'
	brne	ICTMP_H

	; CSI_P1 in AusgabeByte laden
	rcall	CSI_P1_to_AB


	; Ausgabebyte = 0 -> Bildschirm loeschen - Von Cursor bis Ende
	cpi		AusgabeByte, 0
	brne	ICTMP_G1

	; Fuellzeichen in temp (geht schneller)
	ldi		temp2, Fuellzeichen 

	push	YL
	push	YH

ICTMP_G0:

	; Fuellzeichen in BWS
	st		Y+, temp2

	ldi		temp, high((maxSpalten*maxZeilen)+BWS)
	cpi		YL, low((maxSpalten*maxZeilen)+BWS)
	cpc		YH, temp
	;
	brlo	ICTMP_G0

	pop		YH
	pop		YL


	rjmp	ICTMP_G9


ICTMP_G1:

	; Ausgabebyte = 1 -> Bildschirm loeschen - Von Anfang bis Cursor
	cpi		AusgabeByte, 1
	brne	ICTMP_G2


	; Fuellzeichen in temp (geht schneller)
	ldi		temp2, Fuellzeichen 

	; Retten der Cursorposition
	mov		Akku_C,	YL
	mov		Akku_D,	YH

	; Anfang BWS
	ldi		YL, low(BWS)
	ldi		YH, high(BWS)

ICTMP_G1A:

	; Fuellzeichen in BWS
	st		Y+, temp2

	cp		YL, Akku_C
	cpc		YH, Akku_D
	;
	brlo	ICTMP_G1A


	rjmp	ICTMP_G9


ICTMP_G2:

	; Ausgabebyte = 2 -> Bildschirm loeschen - Alles lschen
	cpi		AusgabeByte, 2
	brne	ICTMP_G3

	rcall	NTM_CLS_A

	rjmp	ICTMP_G9


ICTMP_G3:

	; Meldung ESC auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	ldi		AusgabeByte, '['
	rcall	NTM_CHAR

	pop		AusgabeByte
	ldi		temp, '0'
	add		AusgabeByte, temp
	rcall	NTM_CHAR

	ldi		AusgabeByte, 'J'
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR


ICTMP_G9:

	; Grundeinstellungen
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X


ICTMP_H:

	; Zeile einfgen = ESC [ 1 L
	cpi		AusgabeByte, 'L'
	brne	ICTMP_I

	; CSI_P1 in AusgabeByte laden
	rcall	CSI_P1_to_AB


	; Ausgabebyte = 1 -> Zeile einfgen
	cpi		AusgabeByte, 1
	brne	ICTMP_H3

	rcall	INSERT_LINE

	rjmp	ICTMP_H9


ICTMP_H3:

	; Meldung ESC auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	ldi		AusgabeByte, '['
	rcall	NTM_CHAR

	pop		AusgabeByte
	ldi		temp, '0'
	add		AusgabeByte, temp
	rcall	NTM_CHAR

	ldi		AusgabeByte, 'L'
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR


ICTMP_H9:

	; Grundeinstellungen
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X


ICTMP_I:

	; Zeile loeschen = ESC [ 1 M
	cpi		AusgabeByte, 'M'
	brne	ICTMP_J

	; CSI_P1 in AusgabeByte laden
	rcall	CSI_P1_to_AB


	; Ausgabebyte = 1 -> Zeile einfgen
	cpi		AusgabeByte, 1
	brne	ICTMP_I3

	rcall	CLEAR_LINE

	rjmp	ICTMP_I9


ICTMP_I3:

	; Meldung ESC auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	ldi		AusgabeByte, '['
	rcall	NTM_CHAR

	pop		AusgabeByte
	ldi		temp, '0'
	add		AusgabeByte, temp
	rcall	NTM_CHAR

	ldi		AusgabeByte, 'M'
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR


ICTMP_I9:

	; Grundeinstellungen
	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X


ICTMP_J:

	; Invers ein / aus - ESC [ P1 m -> wird ignoriert
	cpi		AusgabeByte, 'm'
	brne	ICTMP_K

	rcall	Clear_CSI_P1
	ldi		TermMode, Normal_TM

	rjmp	ICTMP_X

ICTMP_K:


	; Meldung ESC auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	ldi		AusgabeByte, '['
	rcall	NTM_CHAR

	pop		AusgabeByte
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR

	ldi		TermMode, Normal_TM

ICTMP_X:

	; Ruecksprung
	ret
; .....





; TermMode = IBM_CSI_TM_Par_Zeile
ICTMPZ:

	; 30..39H -> Parameter 1
	cpi		AusgabeByte, 0x30
	brlo	ICTMPZ_A

	cpi		AusgabeByte, 0x3A
	brge	ICTMPZ_A

	rcall	AB_to_CSI_P2

	ldi		TermMode, IBM_CSI_TM_Par_Zeile
	rjmp	ICTMPZ_X


ICTMPZ_A:

	; MOVE CURSOR = ESC [ Pn1 ; PN2 H
	cpi		AusgabeByte, 'H'
	brne	ICTMPZ_B

	rcall	SET_CUR_POS

	rcall	Clear_CSI_P1
	rcall	Clear_CSI_P2
	ldi		TermMode, Normal_TM

	rjmp	ICTMPZ_X


ICTMPZ_B:


	; MOVE CURSOR = ESC [ Pn1 ; PN2 f
	cpi		AusgabeByte, 'f'
	brne	ICTMPZ_C

	rcall	SET_CUR_POS

	rcall	Clear_CSI_P1
	rcall	Clear_CSI_P2
	ldi		TermMode, Normal_TM

	rjmp	ICTMPZ_X


ICTMPZ_C:


	; Meldung ESC auf den Bildschirm
	push	AusgabeByte
	rcall	Meldung_ESC

	ldi		AusgabeByte, '['
	rcall	NTM_CHAR

	rcall	CSI_P1_to_AB
	ldi		temp, '0'
	add		AusgabeByte, temp
	rcall	NTM_CHAR

	ldi		AusgabeByte, ';'
	rcall	NTM_CHAR

	rcall	CSI_P2_to_AB
	ldi		temp, '0'
	add		AusgabeByte, temp
	rcall	NTM_CHAR

	pop		AusgabeByte
	rcall	NTM_CHAR

	ldi		AusgabeByte, Fuellzeichen
	rcall	NTM_CHAR

	ldi		TermMode, Normal_TM


ICTMPZ_X:

	; Ruecksprung
	ret
; .....








; setzen der Cursorposition nach CSI_P1 und CSI_P2
SET_CUR_POS:

	clr		temp

	; Setzen der CSI_P1-Adresse
	ldi		YL, low(CSI_P1)
	ldi		YH, high(CSI_P1)

	; CSI_P1 in Akku_A
	ld		Akku_A, Y
	cp		Akku_A, temp
	brne	SET_CUR_POS_A

	inc		Akku_A

	; in Akku_A steht nun der Wert fuer die Zeile (n>=1)

SET_CUR_POS_A:

	; Setzen der CSI_P1-Adresse
	ldi		YL, low(CSI_P2)
	ldi		YH, high(CSI_P2)

	; CSI_P1 in Akku_A
	ld		Akku_B, Y
	cp		Akku_B, temp
	brne	SET_CUR_POS_B

	inc		Akku_B

	; in Akku_B steht nun der Wert fuer die Spalte (m>=1)


SET_CUR_POS_B:

	; Y hat nun den Anfangswert des BWS (1,1)
	ldi		YL, low(BWS)
	ldi		YH, high(BWS)

	; Zaehlen von 0..maxZeilen-1
	dec		Akku_A
	breq	SET_CUR_POS_D


SET_CUR_POS_C:

	adiw 	XL, maxSpalten_Half
	adiw 	XL, maxSpalten_Half	 

	dec		Akku_A

	brne	SET_CUR_POS_C


SET_CUR_POS_D:

	; Zaehlen von 0..maxSpalten-1
	dec		Akku_B
	breq	SET_CUR_POS_F


SET_CUR_POS_E:

	adiw 	XL, 1

	dec		Akku_B

	brne	SET_CUR_POS_E


SET_CUR_POS_F:


	; Ruecksprung
	ret
; .....








; Meldung ESC auf den Bildschirm
Meldung_ESC:

	ldi		AusgabeByte, 'E'
	rcall	NTM_CHAR

	ldi		AusgabeByte, 'S'
	rcall	NTM_CHAR

	ldi		AusgabeByte, 'C'
	rcall	NTM_CHAR

	; Ruecksprung
	ret
; .....




; AusgabeByte als Einer in CSI_P1 abspeichern 
; CSI_P1 = (CSI_P1*10) + AusgabeByte
AB_to_CSI_P1:

	; Umwandeln Zeichen in Byte
	subi	AusgabeByte, 0x30

	; Sichern der aktuellen Position im BWS 
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Setzen der CSI_P1-Adresse
	ldi		YL, low(CSI_P1)
	ldi		YH, high(CSI_P1)

	; CSI_P1 in temp
	ld		temp, Y

	clr		Akku_A
	cp		temp, Akku_A		; ist CSI_P1 = 0 ?

	breq	AB_10_to_CSI_P1_B	; wenn ja,  dann nur AusgabeByte abspeichern 


	; ansonsten CSI_P1*10 berechnen
	ldi		temp2, 10

; Schleife fuer temp * 10 -> Akku_A
AB_10_to_CSI_P1_A:

	; Akku_A + 10
	add		Akku_A, temp2
		
	; Dekrementieren des Multiplikators
	dec		temp

	; Wiederholen bis temp=0
	breq	AB_10_to_CSI_P1_A

	; nun wird zum Zehnerwert noch der Einerwert addiert
	add		AusgabeByte, Akku_A 

AB_10_to_CSI_P1_B:

	; Abspeichern des CSI_P1
	st		Y, AusgabeByte 

	; Zurueckholen der aktuellen Position im BWS
	mov		YL,Akku_C
	mov		YH,Akku_D


	; Ruecksprung
	ret
; .....



; den Parameter CSI_P1 auf 0 setzen 
Clear_CSI_P1:

	; Sichern der aktuellen Position im BWS 
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Setzen der CSI_P1-Adresse
	ldi		YL, low(CSI_P1)
	ldi		YH, high(CSI_P1)

	; Loeschen des CSI_P1
	clr		temp
	st		Y, temp 

	; Zurueckholen der aktuellen Position im BWS
	mov		YL,Akku_C
	mov		YH,Akku_D


	; Ruecksprung
	ret
; .....



; CSI_P1 in AusgabeByte laden 
CSI_P1_to_AB:

	; Sichern der aktuellen Position im BWS 
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Setzen der CSI_P1-Adresse
	ldi		YL, low(CSI_P1)
	ldi		YH, high(CSI_P1)

	; Abspeichern des CSI_P1
	ld		AusgabeByte, Y 

	; Zurueckholen der aktuellen Position im BWS
	mov		YL,Akku_C
	mov		YH,Akku_D


	; Ruecksprung
	ret
; .....






; AusgabeByte als Einer in CSI_P1 abspeichern 2
; CSI_P2 = (CSI_P2*10) + AusgabeByte
AB_to_CSI_P2:

	; Umwandeln Zeichen in Byte
	subi	AusgabeByte, 0x30

	; Sichern der aktuellen Position im BWS 
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Setzen der CSI_P1-Adresse
	ldi		YL, low(CSI_P2)
	ldi		YH, high(CSI_P2)

	; CSI_P1 in temp
	ld		temp, Y

	clr		Akku_A
	cp		temp, Akku_A		; ist CSI_P2 = 0 ?

	breq	AB_to_CSI_P2_B	; wenn ja,  dann nur AusgabeByte abspeichern 


	; ansonsten CSI_P1*10 berechnen
	ldi		temp2, 10

; Schleife fuer temp * 10 -> Akku_A
AB_to_CSI_P2_A:

	; Akku_A + 10
	add		Akku_A, temp2
		
	; Dekrementieren des Multiplikators
	dec		temp

	; Wiederholen bis temp=0
	breq	AB_to_CSI_P2_A

	; nun wird zum Zehnerwert noch der Einerwert addiert
	add		AusgabeByte, Akku_A 

AB_to_CSI_P2_B:

	; Abspeichern des CSI_P1
	st		Y, AusgabeByte 

	; Zurueckholen der aktuellen Position im BWS
	mov		YL,Akku_C
	mov		YH,Akku_D


	; Ruecksprung
	ret
; .....





; den Parameter CSI_P2 auf 0 setzen 
Clear_CSI_P2:

	; Sichern der aktuellen Position im BWS 
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Setzen der CSI_P1-Adresse
	ldi		YL, low(CSI_P2)
	ldi		YH, high(CSI_P2)

	; Loeschen des CSI_P2
	clr		temp
	st		Y, temp 

	; Zurueckholen der aktuellen Position im BWS
	mov		YL,Akku_C
	mov		YH,Akku_D


	; Ruecksprung
	ret
; .....




; CSI_P2 in AusgabeByte laden 
CSI_P2_to_AB:

	; Sichern der aktuellen Position im BWS 
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Setzen der CSI_P1-Adresse
	ldi		YL, low(CSI_P2)
	ldi		YH, high(CSI_P2)

	; Abspeichern des CSI_P1
	ld		AusgabeByte, Y 

	; Zurueckholen der aktuellen Position im BWS
	mov		YL,Akku_C
	mov		YH,Akku_D


	; Ruecksprung
	ret
; .....










; Einfuegen einer Zeile (Runter-Rollen)
INSERT_LINE:

	; Retten des Cursorstandes
	push	YL
	push	YH

	; Wagenruecklauf
	rcall	NTM_CR_B

	; Zeilenschaltung
	subi	YL, low(-maxSpalten)
	sbci	YH, high(-maxSpalten)
	ldi		temp, high((maxSpalten*maxZeilen)+BWS)
	cpi		YL, low((maxSpalten*maxZeilen)+BWS)
	cpc		YH, temp

	; bei Gleichheit waren wir auf der letzten Zeile
	breq	INSERT_LINE_Y
	; 

	; Ende der Zeile
	mov		Akku_A, YL
	mov		Akku_B, YH


	; Zeilenschaltung
	subi	YL, low(-maxSpalten)
	sbci	YH, high(-maxSpalten)
	ldi		temp, high((maxSpalten*maxZeilen)+BWS)
	cpi		YL, low((maxSpalten*maxZeilen)+BWS)
	cpc		YH, temp

	; bei Gleichheit gibt es nur die letzte Zeile zum loeschen
	breq	INSERT_LINE_X








INSERT_LINE_X:

	mov		YL, Akku_A
	mov		YH, Akku_B

	ldi		temp, maxSpalten
	ldi		temp2, Fuellzeichen
	

INSERT_LINE_X1:
	; Fuellzeichen in BWS
	st		Y+, temp2
	dec		temp
	brne	INSERT_LINE_X1


INSERT_LINE_Y:

	pop		YH
	pop		YL

	; Ruecksprung
	ret
; .....








CLEAR_LINE:



	; Ruecksprung
	ret
; .....








; Loeschen von Zeilenanfang bis Cursor
DELETE_BOL:

	; Sichern der aktuellen Position im BWS 
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Wagenruecklauf
	rcall	NTM_CR_B

	; Fuellzeichen in temp (geht schneller)
	ldi		temp, Fuellzeichen 

	; Fuellen mit Fuellzeichen
DELETE_BOL_A:
	; Fuellzeichen in BWS
	st		Y+, temp

	cp		YL, Akku_C
	cpc		YH, Akku_D

	; Wiederholen solange kleiner
	brlo 	DELETE_BOL_A

	st		Y, temp

	; Ruecksprung
	ret
; .....



; DELETE_EOL - Loeschen bis Zeilenende
DELETE_EOL:

	; Sichern der aktuellen Position im BWS 
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Ermittlung des Zeilenendes

	; Zeilenschaltung
	subi	YL, low(-maxSpalten)
	sbci	YH, high(-maxSpalten)
	ldi		temp, high(maxSpalten*maxZeilen+BWS)
	cpi		YL, low(maxSpalten*maxZeilen+BWS)
	cpc		YH, temp

	brge	DELETE_EOL_A


	; Wagenruecklauf
	rcall	NTM_CR_B

	rjmp	DELETE_EOL_B	


DELETE_EOL_A:

	ldi		YL, low((maxSpalten*maxZeilen)+BWS)
	ldi		YH, high((maxSpalten*maxZeilen)+BWS)

DELETE_EOL_B:
	; nun ist das Zeilenende+1 in Y
	; sichern des Endwertes+1
	mov		Akku_A, YL
	mov		Akku_B, YH

	; Zurueckholen der aktuellen Position im BWS
	mov		YL,Akku_C
	mov		YH,Akku_D

	ldi		temp, Fuellzeichen 

	; Fuellen mit Fuellzeichen
DELETE_EOL_C:
	; Fuellzeichen in BWS
	st		Y+, temp

	cp		YL, Akku_A
	cpc		YH, Akku_B

	; Wiederholen solange kleiner
	brlo 	DELETE_EOL_C


	; Zurueckholen der aktuellen Position im BWS
	mov		YL,Akku_C
	mov		YH,Akku_D

	; Ruecksprung
	ret
; .....



; Loeschen der ganzen Zeile
; der Cursor ist danach am Anfang der Zeile
DELETE_LINE:

	; Wagenruecklauf
	rcall	NTM_CR_B

	; Anfang der Zeile
	mov		Akku_A, YL
	mov		Akku_B, YH


	; Zeilenschaltung
	subi	YL, low(-maxSpalten)
	sbci	YH, high(-maxSpalten)
	ldi		temp, high(maxSpalten*maxZeilen+BWS)
	cpi		YL, low(maxSpalten*maxZeilen+BWS)
	cpc		YH, temp
	;
	brge	DELETE_LINE_A
	; 
	ldi		YL, low((maxSpalten*maxZeilen)+BWS)
	ldi		YH, high((maxSpalten*maxZeilen)+BWS)

	; Ende der Zeile
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Anfang der Zeile laden
	mov		YL, Akku_A
	mov		YH, Akku_B


DELETE_LINE_A:

	; Fuellzeichen in temp (geht schneller)
	ldi		temp, Fuellzeichen 

	; Fuellen mit Fuellzeichen
DELETE_LINE_B:
	; Fuellzeichen in BWS
	st		Y+, temp

	cp		YL, Akku_C
	cpc		YH, Akku_D

	; Wiederholen solange kleiner
	brlo 	DELETE_LINE_B

	; Anfang der Zeile laden
	mov		YL, Akku_A
	mov		YH, Akku_B

	; Ruecksprung
	ret
; .....




; Normal_Terminal_Mode = NTM:
; AusgabeByte in BWS
NTM:

	cpi		AusgabeByte, 0x20	; alles unter dem Leerzeichen sind Steuerzeichen
	brlo	NTM_COMM

NTM_CHAR:
	st		Y+, AusgabeByte
	ldi		temp, high((maxSpalten*maxZeilen)+BWS)
	cpi		YL, low((maxSpalten*maxZeilen)+BWS)
	cpc		YH, temp
	brlo 	NTM_CHAR_A

	rjmp	NTM_ScRo		; Screen-Rollen

NTM_CHAR_A:

	; Ruecksprung
	ret
; .....


; *** Befehle ***

NTM_COMM:

	; 01H = Cursor Home
	cpi		AusgabeByte, 0x01		;Home
	brne	NTM_CurRight

	ldi		YL, low(BWS)
	ldi		YH, high(BWS)

	; Ruecksprung
	ret
; .....



NTM_CurRight:
	; 04 = CURSOR_RIGHT
	cpi		AusgabeByte, 0x04
	brne	NTM_CurUp

NTM_CurRight_B:

	adiw	YH:YL,1
	ldi		temp, high((maxSpalten*maxZeilen)+BWS)
	cpi		YL, low((maxSpalten*maxZeilen)+BWS)
	cpc		YH, temp
	brlo 	NTM_CurRight_A

	ldi YL, low((maxSpalten*maxZeilen)+BWS-1)
	ldi YH, high((maxSpalten*maxZeilen)+BWS-1)

NTM_CurRight_A:

	; Ruecksprung
	ret
; .....


NTM_CurUp:
	; 05 = CURSOR_UP
	cpi		AusgabeByte, 0x05
	brne	NTM_LF


NTM_CurUp_B:

	sbiw 	YH:YL, maxSpalten_Half	
	sbiw 	YH:YL, maxSpalten_Half	

	ldi		temp, high(BWS)
	cpi		YL, low(BWS)
	cpc		YH, temp
	brge 	NTM_CurUp_A

	ldi YL, low(BWS)
	ldi YH, high(BWS)

NTM_CurUp_A:

	; Ruecksprung
	ret
; .....







NTM_LF:
	; 0AH = Line Feed (Zeilenschaltung)
	cpi		AusgabeByte, 0x0A			;Line Feed
	brne	NTM_CLS

	subi	YL, low(-maxSpalten)
	sbci	YH, high(-maxSpalten)
	ldi		temp, high(maxSpalten*maxZeilen+BWS)
	cpi		YL, low(maxSpalten*maxZeilen+BWS)
	cpc		YH, temp

	brge	NTM_ScRo

	; Ruecksprung
	ret
; .....


NTM_ScRo:
	; *** Screen-Rollen ***

	; Laden der BWS-Start-Adresse (Ziel) und Sichern in Akku_C und Akku_D
	; "Position x"
	ldi		YL, low(BWS)
	mov		Akku_C, YL
	ldi		YH, high(BWS)
	mov		Akku_D, YH

	; Laden der Adresse fuer die erste Spalte der zweiten Zeile
	; "Position x plus eine Zeile"
	ldi		YL, low(maxSpalten+BWS)
	ldi		YH, high(maxSpalten+BWS)


	; Laden Zeilenzaehler (von Zeile 2 bis zur letzten Zeile = maxZeilen-1) 
	ldi		temp, maxZeilen-1
	mov		Akku_A, temp


NTM_ScRo_2:

		; Laden des Spaltenzaehlers in Akku_B
		ldi		temp, maxSpalten/2
		mov		Akku_B, temp

NTM_ScRo_1:

			; Laden von 2 aufeinanderfolgenden Zeichen von der
			; "Position x plus eine Zeile" in temp und temp2
			ld		temp, Y+
			ld		temp2, Y+

			; Retten der Adresse fuer "Position x plus eine Zeile" 
			push	YL
			push	YH

			; Laden der Adresse fuer "Position x"
			mov		YL, Akku_C
			mov		YH, Akku_D

			; Abspeichern der beiden vorher geladenen Werte
			; auf der Position x und x+1
			st		Y+, temp
			st		Y+, temp2

			; wieder sichern der aktuellen "Position x"
			mov		Akku_C, YL
			mov		Akku_D, YH

			; zurueckholen der "Position x plus eine Zeile"
			pop		YH
			pop		YL

			; herunterzaehlen des Spaltenzaehlers
			dec		Akku_B

			; wiederholen, bis alle Spalten der Zeile durchlaufen sind
			brne	NTM_ScRo_1

		; herunterzaehlen des Zeilenzaehlers
		dec		Akku_A
	
		; Wiederholen, bis alle Zeilen abgearbeitet wurden 
		brne	NTM_ScRo_2


	; Loeschen der letzten Zeile


	; laden Adresse der 1. Spalte in der letzten Zeile
	ldi		YL, low(maxSpalten*(maxZeilen-1)+BWS)
	ldi		YH, high(maxSpalten*(maxZeilen-1)+BWS)

	; Laden des Zaehlers ueber alle Spalten der letzten Zeile
	ldi		temp, maxSpalten
	mov		Akku_B, temp

	; Laden des Fuellzeichens (geht so schneller)
	ldi		temp, Fuellzeichen

NTM_ScRo_3:

	; Fuellzeichen in BWS
	st		Y+, temp

	; naechste Spalte
	dec		Akku_B
	; Wiederholen, bis Zeile beendet ist
	brne	NTM_ScRo_3


	; aktueller Cursor auf 1. Spalte in der letzten Zeile 
	ldi		YL, low(maxSpalten*(maxZeilen-1)+BWS)
	ldi		YH, high(maxSpalten*(maxZeilen-1)+BWS)

	; Ruecksprung
	ret
; .....


NTM_CLS:

	; 0CH = CLS - Clear Screen
	cpi		AusgabeByte,0x0C			;Clear all
	brne	NTM_CR

NTM_CLS_A:
	; Laden Y mit Adresse BWS
	ldi		YL, low(BWS)
	ldi		YH, high(BWS)
	; temp ist Fuellzeichen
	ldi		temp, Fuellzeichen
	; temp2 ist Ende
	ldi		temp2, high((maxSpalten*maxZeilen)+BWS)
NTM_CLS_B:
	; Fuellzeichen in BWS
	st		Y+, temp
	cpi		YL, low((maxSpalten*maxZeilen)+BWS)
	cpc		YH, temp2
	;
	brne	NTM_CLS_B		; wiederholen bis Y = Endewert hat

	; Laden Y mit 1. Spalte und 1. Zeile im BWS
	ldi		YL, low(BWS)
	ldi		YH, high(BWS)

	; Ruecksprung
	ret
; .....


NTM_CR:

	; 0DH = Carridge Return (Wagenruecklauf)
	cpi		AusgabeByte, 0x0D			; CR
	brne	NTM_Cur_Left

NTM_CR_B:

	; Laden temp und temp2 mit Position 1 der letzten Zeile
	ldi		temp, low(maxSpalten*(maxZeilen-1)+BWS)	; Anfang unterste Zeile
	ldi		temp2, high(maxSpalten*(maxZeilen-1)+BWS)

NTM_CR_1:
	; Vergleich der aktuellen Cursorposition mit Position 1 der Zeile
	cp		YL, temp
	cpc		YH, temp2
	brsh	NTM_CR_2		; Position an erster Stelle der aktuellen Zeile gefunden

	subi	temp, low(maxSpalten)
	sbci	temp2, high(maxSpalten)
	rjmp	NTM_CR_1

NTM_CR_2:
	; wenn die Position gefunden wurde, so wird sie in Y geladen
	mov		YL, temp
	mov		YH, temp2

	; Ruecksprung
	ret
; .....


NTM_Cur_Left:

	; 13H = CURSOR_Left
	cpi		AusgabeByte, 0x13
	brne	NTM_Cur_Down


NTM_Cur_Left_B:

	; Cursor-Position speichern
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Cursor-Position - 1
	sbiw 	YH:YL, 1	

	; Ist Cursor-Position noch im BWS ?
	ldi		temp, high(BWS)
	cpi		YL, low(BWS)
	cpc		YH, temp
	brge 	NTM_Cur_Left_A

	; ... wenn nicht, Laden der alten Cursor-Position
	mov		YL,Akku_C
	mov		YH,Akku_D

NTM_Cur_Left_A:

	; Ruecksprung
	ret
; .....


NTM_Cur_Down:

	; 18H = CURSOR_DOWN
	cpi		AusgabeByte, 0x18
	brne	NTM_ESC


NTM_Cur_Down_B:

	; Cursor-Position speichern
	mov		Akku_C, YL
	mov		Akku_D, YH

	; Cursor-Position + eine Zeile
	adiw 	YH:YL, maxSpalten_Half	
	adiw 	YH:YL, maxSpalten_Half	

	; Ist Cursor-Position noch im BWS ?
	ldi		temp, high((maxSpalten*maxZeilen)+BWS)
	cpi		YL, low((maxSpalten*maxZeilen)+BWS)
	cpc		YH, temp
	brlo 	NTM_Cur_Down_A

	; ... wenn nicht, Laden der alten Cursor-Position
	mov		YL,Akku_C
	mov		YH,Akku_D

NTM_Cur_Down_A:

	; Ruecksprung
	ret
; .....


NTM_ESC:

	; 1BH = Escape
	cpi		AusgabeByte, 0x1B
	brne	NTM_End

	ldi		TermMode, IBM_ESC_TM

	; Ruecksprung
	ret
; .....









NTM_End:


	; Ruecksprung
	ret

; ...........................









;*** CG ROM Daten *** (8x10 Zeichensatz)

.org 1024



.if (Zeichenhoehe==8)
font:
; Zeichenzeile=1
.db 0x00,0xE7,0xE7,0xC6,0x01,0x83,0x01,0x00,0x00,0x00,0x00,0xF0,0xC3,0x00,0xF7,0x99	; 0FH
.db 0x08,0x20,0x81,0x66,0xF7,0xE7,0x00,0x81,0x81,0x81,0x00,0x00,0x00,0x00,0x00,0x00	; 1FH
.db 0x00,0x03,0xC6,0xC6,0x03,0x00,0x83,0x06,0x81,0x06,0x00,0x00,0x00,0x00,0x00,0x60	; 2FH
.db 0x87,0x03,0x87,0x87,0xC1,0xCF,0x83,0xCF,0x87,0x87,0x00,0x00,0x81,0x00,0x06,0x87	; 3FH
.db 0xC7,0x03,0xCF,0xC3,0xCF,0xEF,0xEF,0xC3,0xCC,0x87,0xE1,0x6E,0x0F,0x6C,0x6C,0x83	; 4FH
.db 0xCF,0x87,0xCF,0x87,0xCF,0xCC,0xCC,0x6C,0x6C,0xCC,0xEF,0x87,0x0C,0x87,0x01,0x00	; 5FH
.db 0x03,0x00,0x0E,0x00,0xC1,0x00,0x83,0x00,0x0E,0x03,0x81,0x0E,0x07,0x00,0x00,0x00	; 6FH
.db 0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x81,0x0E,0x67,0x01	; 7FH
.db 0x87,0x00,0x81,0xE7,0xCC,0x06,0xC3,0x00,0xE7,0xCC,0x06,0xCC,0xC7,0x06,0xCC,0x03	; 8FH
.db 0x81,0x00,0xE3,0x87,0x00,0x06,0x87,0x06,0x00,0x6C,0xCC,0x00,0x83,0xA3,0x00,0xE0	; 9FH
.db 0x81,0x81,0xC0,0xC0,0x67,0x67,0xC3,0xC3,0x03,0xC3,0x00,0x6E,0x6E,0x00,0x00,0x00	; AFH
.db 0x22,0x55,0xDD,0x81,0x81,0xC0,0x87,0x0C,0xC3,0x63,0x63,0x00,0x63,0x81,0xCC,0x00	; BFH
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x67,0x67,0x63,0x00,0x63,0x00,0x63,0x00,0x63,0x00	; CFH
.db 0x8D,0xCF,0x87,0xCC,0x06,0x00,0x81,0x87,0xCC,0x81,0x00,0xFF,0x00,0x81,0x06,0xFF	; DFH
.db 0x81,0x00,0xC7,0x03,0x67,0x67,0x00,0x00,0x0F,0x81,0x87,0x06,0x81,0x81,0x00,0x81	; EFH
.db 0x00,0x03,0x00,0x6E,0xF7,0xE7,0x03,0x00,0x83,0x00,0x00,0x83,0xC7,0x87,0x00,0x00	; FFH
; Zeichenzeile=2
.db 0x00,0x18,0xFF,0xEF,0x83,0xC7,0x01,0x00,0x00,0x00,0x00,0x70,0x66,0x00,0x36,0xA5	; 0FH
.db 0x0E,0xE0,0xC3,0x66,0xBD,0x3C,0x00,0xC3,0xC3,0x81,0x81,0x03,0x00,0x42,0x81,0xFF	; 1FH
.db 0x00,0x87,0xC6,0xC6,0xC7,0x6C,0xC6,0x06,0x03,0x03,0x66,0x03,0x00,0x00,0x00,0xC0	; 2FH
.db 0xCC,0x0F,0xCC,0xCC,0xC3,0x0C,0x06,0xCC,0xCC,0xCC,0x00,0x00,0x03,0x00,0x03,0xCC	; 3FH
.db 0x6C,0x87,0x66,0x66,0xC6,0x26,0x26,0x66,0xCC,0x03,0xC0,0x66,0x06,0xEE,0x6E,0xC6	; 4FH
.db 0x66,0xCC,0x66,0xCC,0x4B,0xCC,0xCC,0x6C,0x6C,0xCC,0xCC,0x06,0x06,0x81,0x83,0x00	; 5FH
.db 0x03,0x00,0x06,0x00,0xC0,0x00,0xC6,0x00,0x06,0x00,0x00,0x06,0x03,0x00,0x00,0x00	; 6FH
.db 0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x81,0x03,0xCD,0x83	; 7FH
.db 0xCC,0xCC,0x03,0x3C,0x00,0x03,0x66,0x87,0x3C,0x00,0x03,0x00,0x6C,0x03,0x03,0x84	; 8FH
.db 0x03,0x00,0xC6,0xCC,0xCC,0x03,0xCC,0x03,0xCC,0x00,0x00,0x00,0xC6,0xC6,0x00,0xB1	; 9FH
.db 0x03,0x03,0x81,0x81,0xCD,0xCD,0xC6,0x66,0x00,0xA5,0x00,0xC6,0xC6,0x81,0x33,0xCC	; AFH
.db 0x88,0xAA,0x77,0x81,0x81,0x81,0x48,0x06,0x24,0x63,0x63,0x00,0x63,0x81,0xCC,0x00	; BFH
.db 0x81,0x81,0x00,0x81,0x00,0x81,0xCD,0xCD,0x63,0x00,0x63,0x00,0x63,0x00,0x63,0x28	; CFH
.db 0x07,0xC6,0x48,0x00,0x03,0x0C,0x03,0x48,0x00,0x81,0x00,0xFF,0x00,0x81,0x03,0xFF	; DFH
.db 0x03,0x87,0x28,0x81,0xCD,0xCD,0x66,0x0E,0x06,0x03,0x48,0x03,0x03,0x03,0xCF,0x03	; EFH
.db 0x00,0x03,0x00,0xC2,0xBD,0x3C,0x03,0x00,0xC6,0xCC,0x00,0x87,0xE0,0xC0,0x00,0x00	; FFH
; Zeichenzeile=3
.db 0x00,0x5A,0xBD,0xEF,0xC7,0x83,0x83,0x00,0x00,0x00,0x00,0xF0,0x66,0x00,0xF7,0xC3	; 0FH
.db 0x8F,0xE3,0xE7,0x66,0xBD,0x87,0x00,0xE7,0xE7,0x81,0xC0,0x06,0x0C,0x66,0xC3,0xFF	; 1FH
.db 0x00,0x87,0xC6,0xEF,0x0C,0xCC,0x83,0x0C,0x06,0x81,0xC3,0x03,0x00,0x00,0x00,0x81	; 2FH
.db 0xCD,0x03,0xC0,0xC0,0xC6,0x8F,0x0C,0xC0,0xCC,0xCC,0x03,0x03,0x06,0xCF,0x81,0xC0	; 3FH
.db 0xED,0xCC,0x66,0x0C,0x66,0x86,0x86,0x0C,0xCC,0x03,0xC0,0xC6,0x06,0xEF,0x6F,0x6C	; 4FH
.db 0x66,0xCC,0x66,0x0E,0x03,0xCC,0xCC,0x6C,0xC6,0xCC,0x89,0x06,0x03,0x81,0xC6,0x00	; 5FH
.db 0x81,0x87,0xC7,0x87,0xC0,0x87,0x06,0x67,0xC6,0x07,0x87,0x66,0x03,0xCE,0x8F,0x87	; 6FH
.db 0xCD,0x67,0x8D,0xC7,0xC7,0xCC,0xCC,0x6C,0x6C,0xCC,0xCF,0x03,0x81,0x03,0x00,0xC6	; 7FH
.db 0x0C,0x00,0x87,0xC3,0x87,0x87,0xC3,0xCC,0xC3,0x87,0x87,0x07,0x83,0x07,0x87,0x03	; 8FH
.db 0xCF,0xF7,0xCC,0x00,0x00,0x00,0x00,0x00,0x00,0xC7,0xCC,0xC7,0x46,0xEC,0xCC,0x81	; 9FH
.db 0x87,0x07,0x00,0x00,0x00,0x00,0xC6,0x66,0x03,0x5A,0x00,0x87,0x87,0x00,0x66,0x66	; AFH
.db 0x22,0x55,0xDD,0x81,0x81,0x03,0x03,0x03,0x9B,0x6F,0x63,0xEF,0x6F,0xE7,0x87,0x00	; BFH
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x87,0x03,0x73,0xF3,0x7F,0xFF,0x73,0xFF,0x7F,0xEF	; CFH
.db 0x8D,0x66,0xCF,0xCF,0xCF,0x04,0x87,0x87,0x87,0x81,0x00,0xFF,0x00,0x81,0x87,0xFF	; DFH
.db 0xC7,0xCC,0xC7,0xC7,0x00,0xC7,0x66,0x87,0xC7,0xCC,0x00,0xCC,0x00,0xCC,0x00,0x00	; EFH
.db 0x00,0xCF,0x00,0x87,0xBD,0x87,0x00,0x00,0xC6,0x00,0x00,0x81,0xC3,0x83,0xC3,0x00	; FFH
; Zeichenzeile=4
.db 0x00,0x18,0xFF,0xEF,0xEF,0xEF,0xC7,0x00,0x00,0x00,0x00,0xD7,0x66,0x00,0x36,0x7E	; 0FH
.db 0xEF,0xEF,0x81,0x66,0xB7,0xCC,0x00,0x81,0x81,0x81,0xEF,0xEF,0x0C,0xFF,0xE7,0xE7	; 1FH
.db 0x00,0x03,0x00,0xC6,0x87,0x81,0x67,0x00,0x06,0x81,0xFF,0xCF,0x00,0xCF,0x00,0x03	; 2FH
.db 0xCF,0x03,0x83,0x83,0xCC,0xC0,0x8F,0x81,0x87,0xC7,0x03,0x03,0x0C,0x00,0xC0,0x81	; 3FH
.db 0xED,0xCC,0xC7,0x0C,0x66,0x87,0x87,0x0C,0xCF,0x03,0xC0,0x87,0x06,0x6D,0xED,0x6C	; 4FH
.db 0xC7,0xCC,0xC7,0x83,0x03,0xCC,0xCC,0x6D,0x83,0x87,0x03,0x06,0x81,0x81,0x6C,0x00	; 5FH
.db 0x00,0xC0,0x66,0xCC,0xC7,0xCC,0x0F,0xCC,0x67,0x03,0x81,0xC6,0x03,0xEF,0xCC,0xCC	; 6FH
.db 0x66,0xCC,0xC6,0x0C,0x03,0xCC,0xCC,0x6C,0xC6,0xCC,0x89,0x0E,0x00,0xC1,0x00,0x6C	; 7FH
.db 0x0C,0xCC,0xCC,0x60,0xC0,0xC0,0x60,0x0C,0x66,0xCC,0xCC,0x03,0x81,0x03,0xCC,0x87	; 8FH
.db 0x06,0xC0,0xEF,0x87,0x87,0x87,0xCC,0xCC,0xCC,0x6C,0xCC,0xEC,0x0F,0x6D,0x87,0xE7	; 9FH
.db 0xC0,0x03,0x87,0xCC,0x8F,0xCE,0xE3,0xC3,0x06,0x9B,0xCF,0xE7,0x37,0x81,0xCC,0x33	; AFH
.db 0x88,0xAA,0x77,0x81,0x81,0x87,0x87,0x87,0x1A,0x60,0x63,0x60,0x60,0x0C,0xCF,0x00	; BFH
.db 0x81,0x81,0x00,0x81,0x00,0x81,0xC0,0x87,0x03,0x03,0x00,0x00,0x03,0x00,0x00,0xC6	; CFH
.db 0xC0,0x6F,0x06,0x06,0x06,0x0E,0x03,0x03,0x03,0x81,0x00,0xFF,0x00,0x00,0x03,0xFF	; DFH
.db 0x6C,0x8F,0x6C,0x6C,0x87,0x6C,0x66,0xC6,0x66,0xCC,0xCC,0xCC,0xCC,0xCC,0x00,0x00	; EFH
.db 0x00,0x03,0xCF,0x33,0xB7,0xCC,0xCF,0x00,0x83,0x00,0x00,0x81,0xE0,0x06,0xC3,0x00	; FFH
; Zeichenzeile=5
.db 0x00,0xDB,0x3C,0xC7,0xC7,0xEF,0xEF,0x00,0x00,0x00,0x00,0xCC,0xC3,0x00,0x36,0x7E	; 0FH
.db 0x8F,0xE3,0x81,0x66,0xB1,0xCC,0xE7,0xE7,0x81,0xE7,0xC0,0x06,0x0C,0x66,0xFF,0xC3	; 1FH
.db 0x00,0x03,0x00,0xEF,0xC0,0x03,0xCD,0x00,0x06,0x81,0xC3,0x03,0x00,0x00,0x00,0x06	; 2FH
.db 0xCE,0x03,0x06,0xC0,0xEF,0xC0,0xCC,0x03,0xCC,0xC0,0x00,0x00,0x06,0xCF,0x81,0x03	; 3FH
.db 0xED,0xCF,0x66,0x0C,0x66,0x86,0x86,0xEC,0xCC,0x03,0xCC,0xC6,0x26,0x6C,0xEC,0x6C	; 4FH
.db 0x06,0xCD,0x87,0xC1,0x03,0xCC,0xCC,0xEF,0xC6,0x03,0x26,0x06,0xC0,0x81,0x00,0x00	; 5FH
.db 0x00,0xC7,0x66,0x0C,0xCC,0xCF,0x06,0xCC,0x66,0x03,0x81,0x87,0x03,0x6D,0xCC,0xCC	; 6FH
.db 0x66,0xCC,0xC6,0x87,0x03,0xCC,0xCC,0x6D,0x83,0xCC,0x03,0x03,0x81,0x03,0x00,0x6C	; 7FH
.db 0xCC,0xCC,0xCF,0xE3,0xC7,0xC7,0xE3,0xCC,0xE7,0xCF,0xCF,0x03,0x81,0x03,0xCC,0xCC	; 8FH
.db 0x87,0xF7,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x6C,0xCC,0x6D,0x06,0x6E,0x03,0x81	; 9FH
.db 0xC7,0x03,0xCC,0xCC,0xCC,0xCF,0x00,0x00,0x0C,0x9A,0xC0,0x36,0x76,0x81,0x66,0x66	; AFH
.db 0x22,0x55,0xDD,0x81,0x8F,0xCC,0xCC,0xCC,0x9B,0x6F,0x63,0x6F,0xEF,0x0C,0x03,0x8F	; BFH
.db 0xF1,0xFF,0xFF,0xF1,0xFF,0xFF,0xC7,0xCC,0xF3,0x73,0xFF,0x7F,0x73,0xFF,0x7F,0xC6	; CFH
.db 0xC3,0x66,0x87,0x87,0x87,0x00,0x03,0x03,0x03,0x8F,0xF1,0xFF,0xFF,0x81,0x03,0x00	; DFH
.db 0x6C,0xCC,0x6C,0x6C,0xCC,0x6C,0x66,0x87,0xC7,0xCC,0xCC,0xCC,0xCC,0x87,0x00,0x00	; EFH
.db 0xCF,0x03,0x00,0x7E,0xB1,0xCC,0x00,0x00,0x00,0x00,0x81,0xE7,0xC7,0xC7,0xC3,0x00	; FFH
; Zeichenzeile=6
.db 0x00,0x99,0x7E,0x83,0x83,0x6D,0xC7,0x00,0x00,0x00,0x00,0xCC,0x81,0x00,0x76,0xC3	; 0FH
.db 0x0E,0xE0,0xE7,0x00,0xB1,0x87,0xE7,0xC3,0x81,0xC3,0x81,0x03,0xEF,0x42,0xFF,0x81	; 1FH
.db 0x00,0x00,0x00,0xC6,0x8F,0x66,0xCC,0x00,0x03,0x03,0x66,0x03,0x07,0x00,0x03,0x0C	; 2FH
.db 0xCC,0x03,0xCC,0xCC,0xC0,0xCC,0xCC,0x06,0xCC,0x81,0x03,0x07,0x03,0x00,0x03,0x00	; 3FH
.db 0x0C,0xCC,0x66,0x66,0xC6,0x26,0x06,0x66,0xCC,0x03,0xCC,0x66,0x66,0x6C,0x6C,0xC6	; 4FH
.db 0x06,0x87,0xC6,0xCC,0x03,0xCC,0x87,0xEE,0x6C,0x03,0x6C,0x06,0x60,0x81,0x00,0x00	; 5FH
.db 0x00,0xCC,0x66,0xCC,0xCC,0x0C,0x06,0xC7,0x66,0x03,0x81,0xC6,0x03,0x6C,0xCC,0xCC	; 6FH
.db 0xC7,0xC7,0x06,0xC0,0x43,0xCC,0x87,0xEF,0xC6,0xC7,0x46,0x03,0x81,0x03,0x00,0x6C	; 7FH
.db 0x87,0xCC,0x0C,0x66,0xCC,0xCC,0x66,0x87,0x06,0x0C,0x0C,0x03,0x81,0x03,0xCF,0xCF	; 8FH
.db 0x06,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCF,0x6C,0xCC,0x6E,0x6E,0xC6,0x87,0x81	; 9FH
.db 0xCC,0x03,0xCC,0xCC,0xCC,0xCD,0xE7,0xE7,0xCC,0x66,0xC0,0xEC,0xDC,0xC3,0x33,0xCC	; AFH
.db 0x88,0xAA,0x77,0x81,0x81,0xCF,0xCF,0xCF,0x24,0x63,0x63,0x63,0x00,0xE7,0xCF,0x81	; BFH
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xCC,0xCF,0x00,0x63,0x00,0x63,0x63,0x00,0x63,0xEF	; CFH
.db 0xC6,0xC6,0x06,0x06,0x06,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00	; DFH
.db 0x6C,0x8F,0x6C,0x6C,0xCC,0x6C,0xC7,0x06,0x06,0xCC,0xCC,0xCC,0xCF,0x03,0x00,0x00	; EFH
.db 0x00,0x00,0xCF,0xDC,0xB1,0x87,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC3,0x00	; FFH
; Zeichenzeile=7
.db 0x00,0x18,0xFF,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0xCC,0xE7,0x00,0x6E,0xA5	; 0FH
.db 0x08,0x20,0xC3,0x66,0xB1,0xC8,0xE7,0x81,0x81,0x81,0x00,0x00,0x00,0x00,0x00,0x00	; 1FH
.db 0x00,0x03,0x00,0xC6,0x03,0x6C,0x67,0x00,0x81,0x06,0x00,0x00,0x03,0x00,0x03,0x08	; 2FH
.db 0x87,0xCF,0xCF,0x87,0xC0,0x87,0x87,0x06,0x87,0x07,0x03,0x03,0x81,0x00,0x06,0x03	; 3FH
.db 0x87,0xCC,0xCF,0xC3,0xCF,0xEF,0x0F,0xE3,0xCC,0x87,0x87,0x6E,0xEF,0x6C,0x6C,0x83	; 4FH
.db 0x0F,0xC1,0x6E,0x87,0x87,0xCF,0x03,0x6C,0x6C,0x87,0xEF,0x87,0x20,0x87,0x00,0x00	; 5FH
.db 0x00,0x67,0xCB,0x87,0x67,0x87,0x0F,0xC0,0x6E,0x87,0x8D,0x6E,0x87,0x6C,0xCC,0x87	; 6FH
.db 0x06,0xC0,0x0F,0x8F,0x81,0x67,0x03,0xC6,0x6C,0xC0,0xCF,0xC1,0x81,0x0E,0x00,0xEF	; 7FH
.db 0x03,0xE7,0x87,0xF3,0xE7,0xE7,0xF3,0x03,0xC3,0x87,0x87,0x87,0xC3,0x87,0xCC,0xCC	; 8FH
.db 0xCF,0xF7,0xEC,0x87,0x87,0x87,0xE7,0xE7,0xC0,0xC7,0x87,0xC7,0xCF,0x8B,0xCC,0x8D	; 9FH
.db 0xE7,0x87,0x87,0xE7,0xCC,0xCC,0x00,0x00,0x87,0xC3,0x00,0x89,0xF9,0xC3,0x00,0x00	; AFH
.db 0x22,0x55,0xDD,0x81,0x81,0xCC,0xCC,0xCC,0xC3,0x63,0x63,0x63,0x00,0x81,0x03,0x81	; BFH
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xE7,0xCC,0x00,0x63,0x00,0x63,0x63,0x00,0x63,0x28	; CFH
.db 0x83,0xCF,0xCF,0xCF,0xCF,0x00,0x87,0x87,0x87,0x00,0x81,0xFF,0xFF,0x81,0x87,0x00	; DFH
.db 0xC7,0x0C,0xC7,0xC7,0x87,0xC7,0x06,0x0F,0x0F,0x87,0x87,0x87,0xC0,0x87,0x00,0x00	; EFH
.db 0x00,0xCF,0x00,0xF9,0xB1,0xC8,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; FFH
; Zeichenzeile=8
.db 0x00,0xE7,0xE7,0x00,0x00,0x83,0x83,0x00,0x00,0x00,0x00,0x87,0x81,0x00,0x0C,0x99	; 0FH
.db 0x00,0x00,0x81,0x00,0x00,0x8F,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 1FH
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00	; 2FH
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00	; 3FH
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 4FH
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF	; 5FH
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8F,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00	; 6FH
.db 0x0F,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8F,0x00,0x00,0x00,0x00,0x00,0x00	; 7FH
.db 0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 8FH
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8F,0x00,0x00,0x00,0x00,0x00,0x00,0x07	; 9FH
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF1,0x30,0x81,0x00,0x00	; AFH
.db 0x88,0xAA,0x77,0x81,0x81,0x00,0x00,0x00,0x00,0x63,0x63,0x63,0x00,0x81,0x03,0x81	; BFH
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x00,0x00,0x00,0x63,0x00,0x63,0x63,0x00,0x63,0x00	; CFH
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xFF,0xFF,0x00,0x00,0x00	; DFH
.db 0x00,0x0C,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x8F,0x00,0x00,0x00	; EFH
.db 0x00,0x00,0x00,0x30,0x00,0x8F,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; FFH

.endif



.if (Zeichenhoehe==10)
font:
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x7F
.db 0x00,0x00,0x80,0x80,0x00,0x01,0x81,0x00,0x80,0x00,0x01,0x00,0x01,0x01,0x41,0x80,0x40,0x00,0x00,0x81,0x00,0x01,0x80,0x01,0x00,0x41,0x41,0x00,0x00,0x00,0x00,0x00	; 0x9F
.db 0x80,0x80,0x80,0x80,0x41,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x41,0xA0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x41,0x01,0x00,0x40,0x80,0x41,0x00,0x00,0x00,0x00,0x00,0x01,0xC7	; 0xDF
.db 0x80,0x00,0x81,0x01,0x41,0x41,0x00,0x00,0x00,0x40,0x80,0x01,0x80,0x40,0xC7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x41,0x41,0x40,0x00,0x01,0x80,0x80,0x01,0x81,0x00,0x00,0x00,0x00,0x80,0x81,0x80,0x81,0x81,0x80,0xC3,0x81,0xC3,0x81,0x81,0x00,0x00,0x00,0x00,0x00,0x81	; 0x3F
.db 0xC3,0x80,0xC7,0xE1,0xC7,0xE3,0xE3,0xE3,0xE7,0xC1,0xC1,0x67,0x07,0x3C,0x66,0xC3,0xC3,0xC3,0xC3,0xC1,0xC7,0x63,0x66,0x66,0x66,0x6C,0xC3,0x81,0x01,0x81,0x80,0x00	; 0x5F
.db 0x01,0x00,0x06,0x00,0xC0,0x00,0x80,0x00,0x06,0x80,0x80,0x06,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x01,0x00,0x00	; 0x7F
.db 0xE1,0x42,0x01,0x41,0x41,0x80,0x81,0x00,0x41,0x42,0x80,0x82,0x82,0x80,0x00,0x41,0x80,0x00,0xF1,0x42,0x42,0x80,0x01,0x80,0x82,0x00,0x00,0x00,0x81,0xE3,0x00,0x40	; 0x9F
.db 0x01,0x01,0x01,0x01,0x82,0x82,0x00,0x00,0x00,0x81,0x00,0x02,0x02,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x01,0x41,0x40,0x81,0x80,0x80,0x00,0x00,0x00,0x41,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x41,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x42,0x03,0xC3,0x41,0x00,0x80,0x80,0x80,0x41,0x00,0x00,0x00,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x01,0x81,0x42,0x80,0x82,0x82,0x00,0x00,0x06,0x80,0x41,0x80,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x03,0xC0,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x81,0x80,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x41,0x41,0xC1,0x26,0x82,0x80,0x01,0x80,0x81,0x00,0x00,0x00,0x00,0x80,0x42,0x81,0x42,0x42,0x81,0x02,0x02,0x42,0x42,0x42,0x00,0x00,0x00,0x00,0x00,0x42	; 0x3F
.db 0x24,0x80,0x22,0x22,0x22,0x21,0x21,0x24,0x42,0x80,0x80,0x42,0x02,0x66,0x43,0x24,0x21,0x24,0x21,0x42,0x45,0x22,0x24,0x24,0x42,0x44,0x42,0x01,0x01,0x80,0x41,0x00	; 0x5F
.db 0x80,0x00,0x02,0x00,0x40,0x00,0x01,0x00,0x02,0x00,0x00,0x02,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x01,0x41,0x80	; 0x7F
.db 0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xE3,0x00,0x92,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x22,0x00,0x02,0x64,0x00,0x80	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x66,0x80,0x81,0x80,0x42,0x00,0x22,0x22,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x42,0x80,0x80,0x00,0x00,0x00,0x41,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x81,0x03,0x21,0xE3,0xE3,0xE3,0x00,0xC1,0xC1,0xC1,0x00,0x00,0x80,0x00,0x80,0xC1,0x00	; 0xDF
.db 0xC3,0x42,0xC3,0xC3,0x00,0xC3,0x00,0x06,0xC3,0x22,0x22,0x22,0x00,0x63,0x00,0x01,0x00,0x00,0x00,0x21,0xC1,0x42,0x00,0x00,0x80,0x41,0x00,0x80,0x80,0x80,0x80,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x00,0xE3,0x22,0x46,0x61,0x00,0x01,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x42,0x80,0x40,0x40,0x81,0x83,0x02,0x80,0x42,0x42,0x80,0x80,0x80,0x00,0x02,0x40	; 0x3F
.db 0x99,0x41,0x22,0x02,0x22,0x01,0x01,0x04,0x42,0x80,0x80,0x82,0x02,0x66,0x43,0x24,0x21,0x24,0x21,0x02,0x01,0x22,0x42,0x24,0x81,0x82,0x80,0x01,0x01,0x80,0x00,0x00	; 0x5F
.db 0x00,0x81,0x83,0x81,0xC1,0x81,0x01,0xC1,0x82,0x80,0x80,0x82,0x80,0x2D,0x86,0x81,0x86,0xC1,0x80,0xC0,0x81,0x42,0x42,0x22,0x42,0x42,0xC1,0x80,0x80,0x01,0x82,0x80	; 0x7F
.db 0x02,0x42,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x01,0x01,0x80,0x80,0x80,0x21,0x63,0x82,0x81,0x81,0x81,0x42,0x42,0x42,0x22,0x22,0xE1,0x01,0xA4,0x42,0x80	; 0x9F
.db 0x81,0x01,0x81,0x42,0x83,0x43,0x81,0x81,0x00,0xA5,0x00,0x42,0x42,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xA5,0x80,0x80,0x00,0x00,0x40,0x80,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x81,0x80,0x21,0x21,0x21,0x21,0x80,0x80,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x24,0x42,0x24,0x24,0x81,0x24,0x00,0x83,0x22,0x22,0x22,0x22,0x42,0x41,0x00,0x00,0x00,0x80,0x00,0x43,0xC1,0x01,0x80,0x00,0x00,0x00,0x00,0x80,0x81,0x81,0x80,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x00,0x41,0x81,0x80,0xA2,0x00,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x80,0x42,0x80,0x80,0x80,0x82,0x40,0x83,0x80,0x81,0xC1,0x00,0x00,0x01,0x83,0x01,0x80	; 0x3F
.db 0x9A,0x41,0xC3,0x02,0x22,0xC1,0xC1,0xE4,0xC3,0x80,0x80,0x03,0x02,0xA5,0xC2,0x24,0xC1,0x24,0xC1,0x81,0x01,0x22,0x42,0xA5,0x81,0x01,0x01,0x01,0x01,0x80,0x00,0x00	; 0x5F
.db 0x00,0x40,0x42,0x42,0x42,0x42,0x81,0x42,0x43,0x80,0x80,0x03,0x80,0xD6,0x43,0x42,0x43,0x42,0x01,0x01,0x01,0x42,0x42,0xA2,0x42,0x42,0x40,0x80,0x80,0x01,0x00,0x80	; 0x7F
.db 0x02,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x42,0x01,0x01,0x80,0x41,0x41,0x01,0x90,0xE4,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x22,0x62,0x83,0xA4,0x81,0xC1	; 0x9F
.db 0x40,0x01,0x42,0x42,0x42,0x43,0x00,0x81,0x80,0x25,0x00,0x80,0x80,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x41,0x41,0x41,0xA5,0x80,0x80,0x80,0x80,0xC1,0xC1,0x80	; 0xBF
.db 0x80,0x00,0x00,0x80,0x00,0x80,0x40,0x41,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x42,0x81,0xA3,0x01,0x01,0x01,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x24,0xC3,0x24,0x24,0x42,0x24,0x82,0x42,0x22,0x22,0x22,0x22,0x42,0x41,0x00,0x00,0x00,0xC1,0x83,0x80,0xC0,0x82,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x80,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x00,0xE3,0x40,0x01,0x42,0x00,0x01,0x80,0x00,0xC1,0x00,0x81,0x00,0x01,0x42,0x80,0x01,0x40,0xC3,0x40,0x42,0x01,0x42,0x40,0x00,0x00,0x02,0x00,0x80,0x01	; 0x3F
.db 0x9A,0xE3,0x22,0x02,0x22,0x01,0x01,0x24,0x42,0x80,0x80,0x82,0x02,0xA5,0xC2,0x24,0x01,0x24,0x41,0x40,0x01,0x22,0x42,0xA5,0x81,0x01,0x02,0x01,0x80,0x80,0x00,0x00	; 0x5F
.db 0x00,0xC1,0x42,0x02,0x42,0xC3,0x01,0x42,0x42,0x80,0x80,0x03,0x80,0x94,0x42,0x42,0x42,0x42,0x01,0x80,0x01,0x42,0x42,0xA2,0x81,0x42,0x80,0x81,0x80,0x80,0x00,0x80	; 0x7F
.db 0x02,0x42,0xC3,0xC1,0xC1,0xC1,0xC1,0x02,0xC3,0xC3,0xC3,0x01,0x01,0x80,0x41,0x41,0xC1,0xF3,0x87,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x22,0xA2,0x01,0x25,0x81,0x80	; 0x9F
.db 0xC1,0x01,0x42,0x42,0x42,0xC2,0x81,0x00,0x80,0x42,0xC3,0x61,0x21,0x80,0x41,0x82,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x42,0x00,0x00,0xC1,0xC1,0x02,0x80,0xC1	; 0xBF
.db 0xC1,0x81,0x81,0xC1,0x81,0xC1,0xC1,0x41,0xC1,0xC1,0x81,0x81,0x00,0x81,0xC1,0x00,0x42,0x21,0xC1,0xC1,0xC1,0x80,0x80,0x80,0x80,0xC1,0xC1,0x00,0x00,0x00,0x80,0x00	; 0xDF
.db 0x24,0x22,0x24,0x24,0x42,0x24,0x82,0x42,0x22,0x22,0x22,0x22,0x42,0x80,0x00,0x00,0x80,0x80,0x00,0x21,0x40,0x41,0xC1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x41,0x22,0x62,0x42,0x00,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x01,0x42,0x80,0x42,0x42,0x80,0x42,0x42,0x01,0x42,0x40,0x00,0x00,0x01,0x83,0x01,0x00	; 0x3F
.db 0x69,0x22,0x22,0x22,0x22,0x21,0x01,0x24,0x42,0x80,0x82,0x42,0x42,0x24,0x42,0x24,0x01,0x24,0x21,0x42,0x01,0x22,0x81,0x42,0x42,0x01,0x42,0x01,0x80,0x80,0x00,0x00	; 0x5F
.db 0x00,0x42,0x42,0x42,0x42,0x02,0x01,0xC2,0x42,0x80,0x80,0x82,0x80,0x94,0x42,0x42,0x42,0x42,0x01,0x40,0x01,0xC2,0x81,0x41,0x42,0x42,0x01,0x80,0x80,0x01,0x00,0x80	; 0x7F
.db 0x22,0xC2,0x02,0x42,0x42,0x42,0x42,0x42,0x02,0x02,0x02,0x01,0x01,0x80,0xC3,0xE3,0x01,0x84,0x98,0x42,0x42,0x42,0xC2,0xC2,0x42,0x22,0x22,0x23,0x02,0x26,0x42,0x80	; 0x9F
.db 0x42,0x01,0x42,0xC2,0x42,0xC2,0x00,0x00,0x01,0x81,0x40,0x22,0x62,0x80,0x82,0x41,0x80,0x80,0x80,0x80,0x80,0xE3,0xE3,0xE3,0x81,0x80,0x80,0x80,0x80,0x02,0xC1,0x80	; 0xBF
.db 0x80,0x00,0x00,0x80,0x00,0x80,0x42,0xE3,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x00,0x42,0x21,0x01,0x01,0x01,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x24,0x22,0x24,0x24,0x42,0x24,0x82,0x42,0xC3,0x22,0x22,0x22,0x42,0x80,0x00,0x00,0x00,0x00,0x83,0x62,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00	; 0xFF

.db 0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x00,0x41,0xC1,0x64,0xA1,0x00,0x01,0x80,0x00,0x00,0x80,0x00,0x80,0x01,0x81,0x80,0xC3,0x81,0xC1,0x81,0x81,0x01,0x81,0x81,0x80,0x80,0x80,0x00,0x02,0x01	; 0x3F
.db 0x04,0x77,0xC7,0xC1,0xC7,0xE3,0x83,0xE3,0xE7,0xC1,0x03,0x67,0xC7,0x7E,0x47,0xC3,0x83,0xC3,0xA3,0x83,0x83,0xC1,0x81,0x42,0x66,0x83,0xC3,0x01,0x80,0x80,0x00,0x00	; 0x5F
.db 0x00,0xC1,0x81,0x81,0xC1,0x81,0x81,0x41,0x42,0x80,0x80,0xC2,0x80,0x94,0x42,0x81,0x83,0xC1,0x01,0x81,0x80,0x41,0x81,0x41,0x42,0x81,0xC1,0x80,0x80,0x01,0x00,0x80	; 0x7F
.db 0xC1,0x41,0x81,0xC1,0xC1,0xC1,0xC1,0x81,0x81,0x81,0x81,0x01,0x01,0x80,0x22,0x22,0x21,0x63,0xFC,0x81,0x81,0x81,0x41,0x41,0x81,0x22,0x22,0xC3,0xC3,0xC7,0x00,0x80	; 0x9F
.db 0xC1,0x01,0x81,0x41,0x42,0x42,0x00,0x00,0x02,0x00,0x00,0x60,0x20,0x80,0x41,0x82,0x80,0x80,0x80,0x80,0x80,0x22,0x22,0x22,0x00,0x80,0x80,0x00,0x00,0xC1,0x80,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x22,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x81,0xC3,0x21,0x21,0x21,0x80,0x80,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x24,0xC2,0x24,0x24,0x81,0x24,0x43,0x83,0x06,0x22,0x22,0x22,0x81,0x80,0x00,0x00,0x00,0xC1,0x00,0x20,0x40,0x42,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00	; 0xFF

.db 0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x80,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00	; 0x3F
.db 0xC3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x80,0x00,0x00	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x02,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x80,0x01,0x00,0x80	; 0x7F
.db 0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x77,0xE3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC1,0xC1,0x00,0x00,0x00,0x00,0x82	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x67,0x00,0x00,0x42,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x77,0x77,0x77,0x00,0x80,0x80,0x00,0x00,0x01,0x00,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0xE3,0xE3,0xE3,0x00,0xC1,0xC1,0xC1,0x00,0x00,0x80,0x00,0x80,0xC1,0x00	; 0xDF
.db 0xC3,0x00,0xC3,0xC3,0x00,0xC3,0x02,0x02,0x00,0xC1,0xC1,0xC1,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00	; 0xFF

.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x81,0x00,0xC7	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x07,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x80,0x00,0x01,0x00,0x00	; 0x7F
.db 0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x01	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC7,0x80,0x00,0x00	; 0xDF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x07,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00	; 0xFF
.endif

.if (Zeichenhoehe==12)
font:
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00	; 0x5F
.db 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x7F
.db 0x00,0x00,0xC0,0x03,0x00,0x0C,0x83,0x00,0x03,0x00,0x0C,0x00,0x01,0x06,0x00,0x87,0xC0,0x00,0x00,0x03,0x00,0x0C,0x03,0x0C,0x00,0x00,0xCC,0x00,0xC3,0x00,0x00,0xE0	; 0x9F
.db 0xC0,0xC0,0xC0,0xC0,0x00,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x55,0xD6,0x81,0x81,0xC0,0x87,0x06,0x00,0x66,0x66,0x00,0x66,0x00,0xCC,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x00,0x67,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0xCC,0x00,0x87,0x00,0x06,0x00,0x81,0x87,0x00,0x81,0x00,0xFF,0x00,0x00,0x06,0xFF	; 0xDF
.db 0x81,0x00,0x87,0x06,0x00,0x67,0x00,0x00,0x00,0x81,0x87,0x06,0x60,0x81,0x00,0xC0,0x00,0x00,0x00,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0xE7,0xE7,0x00,0x01,0x81,0x81,0x00,0x00,0x00,0x00,0xE3,0xC3,0x00,0xF7,0x00,0x08,0x20,0x81,0x66,0xF7,0xE7,0x00,0x81,0x81,0x81,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x03,0x66,0xC6,0x03,0x00,0x07,0x03,0xC0,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0xC7,0x01,0x87,0x87,0xC0,0xCF,0x83,0xEF,0x87,0x87,0x00,0x00,0xC0,0x00,0x06,0x87	; 0x3F
.db 0xC7,0x03,0xCF,0xC3,0x8F,0xEF,0xEF,0xC3,0xCC,0x87,0xE1,0x6E,0x0F,0x6C,0x6C,0x83,0xCF,0x83,0xCF,0x87,0xCF,0xCC,0xCC,0x6C,0xCC,0xCC,0xEF,0xC3,0x00,0xC3,0x83,0x00	; 0x5F
.db 0x03,0x00,0x0E,0x00,0xC1,0x00,0x83,0x00,0x0E,0x81,0xC0,0x0E,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x81,0x0E,0x37,0x00	; 0x7F
.db 0x87,0xCC,0x81,0x87,0xCC,0x06,0xC6,0x00,0x87,0xCC,0x06,0xC6,0x83,0x03,0xCC,0xCC,0x81,0x00,0xE3,0x87,0xCC,0x06,0x87,0x06,0x66,0xCC,0x00,0x00,0x66,0xA3,0x00,0xB1	; 0x9F
.db 0x81,0x81,0x81,0x81,0x67,0xCD,0x87,0x87,0x03,0x83,0x00,0x26,0x36,0x03,0x00,0x00,0x29,0xAA,0xBD,0x81,0x81,0x81,0xCC,0x03,0x83,0x66,0x66,0x00,0x66,0x03,0xCC,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x67,0xCD,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x03,0x8F,0xCC,0xCC,0x03,0x0F,0x03,0xCC,0xCC,0x81,0x00,0xFF,0x00,0x81,0x03,0xFF	; 0xDF
.db 0x03,0x87,0xCC,0x03,0x67,0xCD,0x00,0x00,0x0F,0x03,0xCC,0x03,0xC0,0x03,0xCF,0x81,0x00,0x00,0x00,0x33,0xF7,0xE7,0x00,0x00,0xC3,0xCC,0x00,0x03,0x87,0x87,0x00,0x00	; 0xFF

.db 0x00,0x3C,0xFF,0x44,0x83,0xC3,0xC3,0x00,0x00,0x00,0x00,0xE0,0x66,0x00,0x36,0x81,0x0C,0x60,0xC3,0x66,0xBD,0x36,0x00,0xC3,0xC3,0x81,0x00,0x00,0x00,0x00,0x01,0xEF	; 0x1F
.db 0x00,0x87,0x66,0xC6,0xC7,0x00,0x8D,0x03,0x81,0x03,0x00,0x00,0x00,0x00,0x00,0x20,0x6C,0x03,0xCC,0xCC,0xC1,0x0C,0x06,0x6C,0xCC,0xCC,0x00,0x00,0x81,0x00,0x03,0xCC	; 0x3F
.db 0x6C,0x87,0x66,0x66,0xC6,0x26,0x66,0x66,0xCC,0x03,0xC0,0x66,0x06,0xEE,0x6C,0xC6,0x66,0xC6,0x66,0xCC,0x4B,0xCC,0xCC,0x6C,0xCC,0xCC,0xEC,0x03,0x08,0xC0,0xC6,0x00	; 0x5F
.db 0x81,0x00,0x06,0x00,0xC0,0x00,0xC6,0x00,0x06,0x81,0xC0,0x06,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x81,0x03,0xAD,0x00	; 0x7F
.db 0xCC,0xCC,0x03,0xCC,0xCC,0x03,0xC6,0x00,0xCC,0xCC,0x03,0xC6,0xC6,0x81,0x00,0xCC,0x00,0x00,0x87,0xCC,0xCC,0x03,0xCC,0x03,0x66,0x00,0xCC,0x00,0x06,0xC6,0x00,0x81	; 0x9F
.db 0x03,0x03,0x03,0x03,0xCD,0x00,0xCC,0xCC,0x03,0x44,0x00,0x6E,0x6E,0x03,0x00,0x00,0x94,0x55,0x6B,0x81,0x81,0x00,0x00,0x00,0x44,0x66,0x66,0x00,0x66,0x03,0xCC,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0xCD,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x8D,0xC6,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x81,0x00,0xFF,0x00,0x81,0x00,0xFF	; 0xDF
.db 0x00,0xCC,0x00,0x00,0xCD,0x00,0x00,0x0E,0x06,0x00,0x00,0x00,0x81,0x00,0x00,0x03,0x00,0x03,0x00,0x66,0xBD,0x36,0x03,0x00,0x66,0x00,0x00,0x07,0xC0,0xC0,0x00,0x00	; 0xFF

.db 0x00,0x18,0xFF,0xEE,0xC7,0xC3,0xE7,0x00,0x00,0x00,0x00,0xA3,0x66,0x00,0xF7,0xBD,0x0E,0xE0,0xE7,0x66,0xBD,0x03,0x00,0xE7,0xE7,0x81,0x81,0x03,0x00,0x42,0x01,0xEF	; 0x1F
.db 0x00,0x87,0x66,0xEF,0x0C,0x4C,0x8D,0x03,0x03,0x81,0x66,0x81,0x00,0x00,0x00,0x60,0xEC,0x0F,0xCC,0xC0,0xC3,0x0C,0x0C,0x6C,0xCC,0xCC,0x83,0x83,0x03,0x00,0x81,0xC0	; 0x3F
.db 0x6C,0xCC,0x66,0x6C,0x66,0x06,0x26,0x6C,0xCC,0x03,0xC0,0xC6,0x06,0xEF,0x6E,0x6C,0x66,0x6C,0x66,0xCC,0x03,0xCC,0xCC,0x6C,0xCC,0xCC,0x89,0x03,0x0C,0xC0,0x6C,0x00	; 0x5F
.db 0x00,0x00,0x06,0x00,0xC0,0x00,0x06,0x00,0x06,0x00,0x00,0x06,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x81,0x03,0xEC,0x01	; 0x7F
.db 0xCC,0x00,0x00,0x00,0x00,0x00,0x83,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x87,0xCF,0x00,0x8D,0x00,0x00,0x00,0x00,0x00,0x00,0x87,0xCC,0x00,0x06,0xEC,0x00,0x81	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x6C,0xCC,0xCC,0x00,0xAB,0x00,0xC6,0xC6,0x00,0x00,0x00,0x42,0xAA,0xD6,0x81,0x81,0x03,0x03,0x03,0xAB,0x66,0x66,0x00,0x66,0x87,0xCC,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x00,0x03,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0xC0,0x66,0xCF,0xCF,0xCF,0x03,0x87,0x87,0x87,0x81,0x00,0xFF,0x00,0x81,0x87,0xFF	; 0xDF
.db 0x87,0xCC,0x87,0x87,0x00,0x87,0x00,0x06,0xC7,0xCC,0xCC,0xCC,0x00,0xCC,0x00,0x00,0x00,0x03,0x00,0xC3,0xBD,0x03,0x03,0x00,0x66,0x00,0x00,0x03,0x83,0x81,0xCF,0x00	; 0xFF

.db 0x00,0x5A,0xBD,0xEF,0xEF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x27,0x66,0x00,0x36,0xE7,0x8F,0xE3,0x81,0x66,0xBD,0xC3,0x00,0x81,0x81,0x81,0xC0,0x06,0x0C,0x66,0x83,0xC7	; 0x1F
.db 0x00,0x87,0x42,0xC6,0x0C,0xCC,0x07,0x06,0x06,0xC0,0xC3,0x81,0x00,0x00,0x00,0xC0,0xED,0x03,0xC0,0xC0,0xC6,0x0C,0x0C,0x60,0xCC,0xCC,0x83,0x83,0x06,0xE7,0xC0,0x81	; 0x3F
.db 0xED,0xCC,0x66,0x0C,0x66,0x46,0x46,0x0C,0xCC,0x03,0xC0,0xC6,0x06,0xEF,0x6F,0x6C,0x66,0x6C,0x66,0x0C,0x03,0xCC,0xCC,0x6C,0x87,0xCC,0x81,0x03,0x06,0xC0,0x00,0x00	; 0x5F
.db 0x00,0x87,0xC7,0x87,0xC7,0x87,0x06,0x67,0xC6,0x87,0xC3,0x66,0x81,0xCF,0x8F,0x87,0xCD,0x67,0xCE,0x87,0xCF,0xCC,0xCC,0x6C,0x6C,0x66,0xCF,0x06,0x81,0x81,0x00,0x83	; 0x7F
.db 0x0C,0xCC,0x87,0x87,0x87,0x87,0x8F,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x4C,0xEF,0x8D,0x87,0x87,0x87,0xCC,0xCC,0x66,0xCC,0xCC,0x87,0x06,0x6D,0x00,0xE7	; 0x9F
.db 0x87,0x87,0x87,0xCC,0x8F,0x6E,0xE7,0x87,0x03,0xAA,0x00,0x87,0x87,0x03,0x33,0xCC,0x29,0x55,0xBD,0x81,0x81,0x87,0x87,0x87,0x2A,0x6E,0x66,0xEF,0x6E,0xCC,0x87,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x87,0x87,0x76,0xF7,0x7E,0xFF,0x76,0xFF,0x7E,0x00,0x60,0x66,0x4C,0x4C,0x4C,0x03,0x03,0x03,0x03,0x81,0x00,0xFF,0x00,0x81,0x03,0xFF	; 0xDF
.db 0xCC,0x8D,0xCC,0xCC,0x87,0xCC,0x66,0xC7,0x66,0xCC,0xCC,0xCC,0x66,0xCC,0x00,0x00,0x00,0xCF,0x00,0x8F,0xBD,0xC3,0x00,0x00,0x66,0x00,0x00,0x03,0xC0,0x03,0xCF,0x00	; 0xFF

.db 0x00,0x18,0xFF,0xEF,0xEF,0x7E,0xFF,0x00,0x00,0x00,0x00,0x8F,0xC3,0x00,0x36,0x7E,0xEF,0xEF,0x81,0x66,0xB7,0x66,0x00,0x81,0x81,0x81,0xEF,0xEF,0x0C,0xFF,0x83,0xC7	; 0x1F
.db 0x00,0x03,0x00,0xC6,0x87,0x81,0xAF,0x00,0x06,0xC0,0xFF,0xE7,0x00,0xEF,0x00,0x81,0x6D,0x03,0x81,0x83,0xCC,0x8F,0x8F,0xC0,0x87,0xC7,0x00,0x00,0x0C,0x00,0x60,0x03	; 0x3F
.db 0xED,0xCC,0xC7,0x0C,0x66,0xC7,0xC7,0x0C,0xCF,0x03,0xC0,0x87,0x06,0x6D,0xEF,0x6C,0xC7,0x6C,0xC7,0x07,0x03,0xCC,0xCC,0x6D,0x03,0x87,0x03,0x03,0x03,0xC0,0x00,0x00	; 0x5F
.db 0x00,0xC0,0x66,0xCC,0xCC,0xCC,0x8F,0xCC,0x67,0x81,0xC0,0xC6,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0xE6,0xCC,0x06,0xCC,0xCC,0x6C,0xC6,0x66,0xC8,0x0C,0x00,0xC0,0x00,0xC6	; 0x7F
.db 0x0C,0xCC,0xCC,0xC0,0xC0,0xC0,0xC0,0xCC,0xCC,0xCC,0xCC,0x81,0x81,0x81,0xCC,0xCC,0x0C,0xB1,0xEF,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCC,0xCF,0x6D,0x6C,0x81	; 0x9F
.db 0xC0,0x81,0xCC,0xCC,0xCC,0x6F,0x00,0x00,0x06,0xAB,0xCF,0x03,0x73,0x03,0x66,0x66,0x94,0xAA,0x6B,0x81,0x8F,0xCC,0xCC,0xCC,0x2A,0x60,0x66,0x60,0x60,0x0C,0xCF,0x8F	; 0xBF
.db 0xF1,0xFF,0xFF,0xF1,0xFF,0xFF,0xC0,0xCC,0x06,0x06,0x00,0x00,0x06,0x00,0x00,0x6C,0xE7,0x6F,0x0C,0x0C,0x0C,0xCF,0x03,0x03,0x03,0x8F,0xF1,0xFF,0x00,0x00,0x03,0xFF	; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0x66,0x66,0xCC,0xCC,0xCC,0x66,0xCC,0x00,0x00,0xCF,0x03,0x8F,0x73,0xB7,0x66,0xCF,0x00,0xC3,0x00,0x81,0x87,0x87,0xC7,0xCF,0x00	; 0xFF

.db 0x00,0xDB,0x3C,0xEF,0xC7,0x7E,0xE7,0x00,0x00,0x00,0x00,0xCC,0x81,0x00,0x36,0x7E,0x8F,0xE3,0x81,0x00,0xB1,0x66,0x00,0x81,0x81,0x81,0xC0,0x06,0x0C,0x66,0xC7,0x83	; 0x1F
.db 0x00,0x03,0x00,0xC6,0xC0,0x03,0xED,0x00,0x06,0xC0,0xC3,0x81,0x00,0x00,0x00,0x03,0x6F,0x03,0x03,0xC0,0xEF,0xC0,0xCC,0x81,0xCC,0x81,0x00,0x00,0x06,0xE7,0xC0,0x03	; 0x3F
.db 0xED,0xCF,0x66,0x0C,0x66,0x46,0x46,0xEC,0xCC,0x03,0xCC,0xC6,0x26,0x6C,0xED,0x6C,0x06,0xEC,0xC6,0x81,0x03,0xCC,0xCC,0x6D,0x87,0x03,0x06,0x03,0x81,0xC0,0x00,0x00	; 0x5F
.db 0x00,0xC7,0x66,0x0C,0xCC,0xCF,0x06,0xCC,0x66,0x81,0xC0,0x87,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x67,0x06,0x06,0xCC,0xCC,0x6D,0x83,0x66,0x81,0x06,0x81,0x81,0x00,0x6C	; 0x7F
.db 0x0C,0xCC,0xCF,0xC7,0xC7,0xC7,0xC7,0x0C,0xCF,0xCF,0xCF,0x81,0x81,0x81,0xCC,0xCC,0x8F,0xF7,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCD,0x06,0x6D,0xC6,0x81	; 0x9F
.db 0xC7,0x81,0xCC,0xCC,0xCC,0xED,0xEF,0xEF,0x0C,0x2B,0xC0,0xE6,0xF6,0x87,0xCC,0x33,0x42,0x55,0xD6,0x81,0x81,0xCC,0xCC,0xCC,0x2A,0x60,0x66,0x60,0x60,0x0C,0x03,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xC7,0xCC,0x06,0x06,0x00,0x00,0x06,0x00,0x00,0xC7,0x6C,0x66,0x8F,0x8F,0x8F,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00	; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0x66,0x66,0xCC,0xCC,0xCC,0x66,0x87,0x00,0x00,0x00,0x03,0x00,0xF6,0xB1,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00	; 0xFF

.db 0x00,0x99,0x7E,0xC7,0x83,0x81,0x81,0x00,0x00,0x00,0x00,0xCC,0xE7,0x00,0x76,0xE7,0x0E,0xE0,0xE7,0x00,0xB1,0xC3,0xEF,0xE7,0x81,0xE7,0x81,0x03,0xEF,0x42,0xC7,0x83	; 0x1F
.db 0x00,0x00,0x00,0xEF,0xC0,0x06,0xCC,0x00,0x03,0x81,0x66,0x81,0x00,0x00,0x00,0x06,0x6E,0x03,0x06,0xC0,0xC0,0xC0,0xCC,0x03,0xCC,0x81,0x83,0x83,0x03,0x00,0x81,0x00	; 0x3F
.db 0x0C,0xCC,0x66,0x6C,0x66,0x06,0x06,0x6C,0xCC,0x03,0xCC,0xC6,0x66,0x6C,0xEC,0x6C,0x06,0xED,0x66,0xCC,0x03,0xCC,0xCC,0xC6,0xCC,0x03,0x26,0x03,0xC0,0xC0,0x00,0x00	; 0x5F
.db 0x00,0xCC,0x66,0x0C,0xCC,0x0C,0x06,0xCC,0x66,0x81,0xC0,0xC6,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x06,0x81,0x06,0xCC,0xCC,0x6D,0x83,0x66,0x06,0x03,0x81,0x03,0x00,0x6C	; 0x7F
.db 0xCC,0xCC,0x0C,0xCC,0xCC,0xCC,0xCC,0x0C,0x0C,0x0C,0x0C,0x81,0x81,0x81,0xCF,0xCF,0x0C,0x8D,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCE,0x06,0x6E,0x83,0x81	; 0x9F
.db 0xCC,0x81,0xCC,0xCC,0xCC,0xEC,0x00,0x00,0x0C,0xAA,0xC0,0x3C,0xBD,0x87,0xCC,0x33,0x29,0xAA,0xBD,0x81,0x81,0xCF,0xCF,0xCF,0xAB,0x6E,0x66,0x6E,0xEF,0xCC,0xCF,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xCC,0xCF,0xF7,0x76,0xFF,0x7E,0x76,0xFF,0x7E,0xC6,0x6C,0x66,0x0C,0x0C,0x0C,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00	; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xC7,0xC7,0xCC,0xCC,0xCC,0x66,0x03,0x00,0x00,0x00,0x00,0x00,0xBD,0xB1,0xC3,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00	; 0xFF

.db 0x00,0x3C,0xFF,0x83,0x01,0x81,0x81,0x00,0x00,0x00,0x00,0xCC,0x81,0x00,0x7E,0xBD,0x0C,0x60,0xC3,0x66,0xB1,0xC0,0xEF,0xC3,0x81,0xC3,0x00,0x00,0x00,0x00,0xEF,0x01	; 0x1F
.db 0x00,0x03,0x00,0xC6,0x8F,0xCC,0xCD,0x00,0x81,0x03,0x00,0x00,0x83,0x00,0x83,0x0C,0x6C,0x03,0xCC,0xCC,0xC0,0xCC,0xCC,0x03,0xCC,0x03,0x83,0x83,0x81,0x00,0x03,0x03	; 0x3F
.db 0x0C,0xCC,0x66,0x66,0xC6,0x26,0x06,0x66,0xCC,0x03,0xCC,0x66,0x66,0x6C,0x6C,0xC6,0x06,0xC7,0x66,0xCC,0x03,0xCC,0x87,0xC6,0xCC,0x03,0x6C,0x03,0x60,0xC0,0x00,0x00	; 0x5F
.db 0x00,0xCC,0x66,0xCC,0xCC,0xCC,0x06,0xC7,0x66,0x81,0xC0,0x66,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x06,0xCC,0xC6,0xCC,0x87,0xC6,0xC6,0xC3,0x4C,0x03,0x81,0x03,0x00,0xEF	; 0x7F
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x0C,0x0C,0x0C,0x81,0x81,0x81,0xCC,0xCC,0x4C,0x8D,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0xC3,0xCC,0xCC,0xCC,0x0C,0xC6,0xC6,0x8D	; 0x9F
.db 0xCC,0x81,0xCC,0xCC,0xCC,0x6C,0x00,0x00,0xCC,0x44,0xC0,0x68,0x3B,0x87,0x66,0x66,0x94,0x55,0x6B,0x81,0x81,0xCC,0xCC,0xCC,0x44,0x66,0x66,0x66,0x00,0x87,0x03,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xCC,0xCC,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0xC7,0x6C,0xC6,0x4C,0x4C,0x4C,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00	; 0xDF
.db 0xCC,0x8F,0xCC,0xCC,0xCC,0xCC,0x66,0x06,0x06,0xCC,0xCC,0xCC,0xC3,0x03,0x00,0x00,0x00,0xCF,0x8F,0x3B,0xB1,0xC0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00	; 0xFF

.db 0x00,0xE7,0xE7,0x01,0x00,0xE7,0xE7,0x00,0x00,0x00,0x00,0x87,0x81,0x00,0x6E,0x81,0x08,0x20,0x81,0x66,0xB1,0x6C,0xEF,0x81,0x81,0x81,0x00,0x00,0x00,0x00,0xEF,0x01	; 0x1F
.db 0x00,0x03,0x00,0xC6,0x03,0xC8,0x67,0x00,0xC0,0x06,0x00,0x00,0x83,0x00,0x83,0x08,0xC7,0xCF,0xCF,0x87,0xE1,0x87,0x87,0x03,0x87,0x07,0x00,0x81,0xC0,0x00,0x06,0x03	; 0x3F
.db 0xC7,0xCC,0xCF,0xC3,0x8F,0xEF,0x0F,0xE3,0xCC,0x87,0x87,0x6E,0xEF,0x6C,0x6C,0x83,0x0F,0xC0,0x6E,0x87,0x87,0x87,0x03,0xC6,0xCC,0x87,0xEF,0xC3,0x20,0xC3,0x00,0x00	; 0x5F
.db 0x00,0x67,0xCD,0x87,0x67,0x87,0x0F,0xC0,0x6E,0xE7,0xCC,0x6E,0xE7,0x6C,0xCC,0x87,0xC7,0xC7,0x0F,0x87,0x83,0x67,0x03,0xC6,0x6C,0xC0,0xCF,0xC1,0x81,0x0E,0x00,0x00	; 0x7F
.db 0x87,0x67,0x87,0x67,0x67,0x67,0x67,0x87,0xC7,0xC7,0xC7,0xE7,0xE7,0xE7,0xCC,0xCC,0xCF,0xFE,0xED,0x87,0x87,0x87,0x67,0x67,0xC0,0x87,0x87,0x87,0xEF,0x8B,0x6C,0x07	; 0x9F
.db 0x67,0xE7,0x87,0x67,0xCC,0x6C,0x00,0x00,0x87,0x83,0x00,0xC0,0xF3,0x03,0x33,0xCC,0x42,0xAA,0xD6,0x81,0x81,0xCC,0xCC,0xCC,0x83,0x66,0x66,0x66,0x00,0x03,0x03,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x67,0xCC,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x6C,0xC7,0x8F,0xCF,0xCF,0xCF,0x00,0x87,0x87,0x87,0x00,0x81,0xFF,0xFF,0x81,0x87,0x00	; 0xDF
.db 0x87,0x0C,0x87,0x87,0x87,0x87,0xB7,0x0F,0x0F,0x87,0x87,0x87,0xC0,0x87,0x00,0x00,0x00,0x00,0x00,0xF3,0xB1,0x6C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x00,0xE7,0x00,0xE7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCC,0x00,0x00,0xCC,0x00,0x00,0x00,0x00,0x00,0x06,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00	; 0x7F
.db 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF1,0x30,0x00,0x00,0x00,0x29,0x55,0xBD,0x81,0x81,0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x00,0x03,0x00,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x00,0x00,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xFF,0xFF,0x00,0x00,0x00	; 0xDF
.db 0x00,0x06,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x00,0xE7,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x87,0x00,0x00,0x87,0x00,0x00,0x00,0x00,0x00,0x0F,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00	; 0x7F
.db 0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xAA,0x6B,0x81,0x81,0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x00,0x00,0x00,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x00,0x00,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xFF,0xFF,0x00,0x00,0x00	; 0xDF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF
.endif
